@@ -1,4 +1,3 @@
-# $Id: ProteinStatistics.pm 16123 2009-09-17 12:57:27Z cjfields $
 #
 # BioPerl module for Bio::Align::ProteinStatistics
 #
@@ -69,7 +68,7 @@ Report bugs to the Bioperl bug tracking system to help us keep track
 of the bugs and their resolution. Bug reports can be submitted via the
 web:
 
-  http://bugzilla.open-bio.org/
+  https://github.com/bioperl/bioperl-live/issues
 
 =head1 AUTHOR - Jason Stajich
 
@@ -87,6 +86,7 @@ Internal methods are usually preceded with a _
 
 
 package Bio::Align::ProteinStatistics;
+$Bio::Align::ProteinStatistics::VERSION = '1.7.8';
 use vars qw(%DistanceMethods $Precision $DefaultGapPenalty);
 use strict;
 
@@ -264,11 +264,11 @@ sub _check_ambiguity_protein
 
     if( $t1 ne 'X' && $t1 eq $t2 ) { 
         $n = 1.0;
-    } elsif(  ((($t1 eq 'B' && $t2 eq 'DN') ||
-	       ($t2 eq 'B' && $t2 eq 'DN'))) ||
+    } elsif(  (($t1 eq 'B' && $t2 =~ /[DN]/ ) ||
+	       ($t2 eq 'B' && $t1 =~ /[DN]/ )) ||
 	      
-	      ( ($t1 eq 'Z' && $t2 eq 'EQ') ||
-		($t2 eq 'Z' && $t1 eq 'EQ'))) {
+	      (($t1 eq 'Z' && $t2 =~ /[EQ]/) ||
+	       ($t2 eq 'Z' && $t1 =~ /[EQ]/ ))) {
         $n = 0.5;
     } elsif ( $t1 eq 'X' && $t2 eq 'X' ) {
         $n = 0.0025;
