@@ -1,4 +1,3 @@
-# $Id: mega.pm 16123 2009-09-17 12:57:27Z cjfields $
 #
 # BioPerl module for Bio::AlignIO::mega
 #
@@ -60,7 +59,7 @@ Report bugs to the Bioperl bug tracking system to help us keep track
 of the bugs and their resolution. Bug reports can be submitted the
 web:
 
-  http://bugzilla.open-bio.org/
+  https://github.com/bioperl/bioperl-live/issues
 
 =head1 AUTHOR - Jason Stajich
 
@@ -78,6 +77,7 @@ Internal methods are usually preceded with a _
 
 
 package Bio::AlignIO::mega;
+$Bio::AlignIO::mega::VERSION = '1.7.8';
 use vars qw($MEGANAMELEN %VALID_TYPES $LINELEN $BLOCKLEN);
 use strict;
 
@@ -163,11 +163,11 @@ sub next_aln{
        my $s = $seqs{$seqname};
        $s =~ s/[$Bio::LocatableSeq::GAP_SYMBOLS]+//g;
        my $end = length($s);
-       my $seq = Bio::LocatableSeq->new(-alphabet => $alphabet,
-				       -id => $seqname,
-				       -seq => $seqs{$seqname},
-				       -start => 1,
-				       -end   => $end);
+       my $seq = Bio::LocatableSeq->new('-alphabet'   => $alphabet,
+					'-display_id' => $seqname,
+					'-seq'        => $seqs{$seqname},
+					'-start'      => 1,
+					'-end'        => $end);
 
        $aln->add_seq($seq);
    }
