@@ -1,8 +1,9 @@
-# $Id: AnalysisI.pm,v 1.6 2004/11/16 17:45:38 jason Exp $
 #
 # BioPerl module for Bio::AnalysisI
 #
-# Cared for by Martin Senger <senger@ebi.ac.uk>
+# Please direct questions and support issues to <bioperl-l@bioperl.org>
+#
+# Cared for by Martin Senger <martin.senger@gmail.com>
 # For copyright and disclaimer see below.
 #
 
@@ -18,7 +19,7 @@ This is an interface module - you do not instantiate it.
 Use C<Bio::Tools::Run::Analysis> module:
 
   use Bio::Tools::Run::Analysis;
-  my $tool = new Bio::Tools::Run::Analysis (@args);
+  my $tool = Bio::Tools::Run::Analysis->new(@args);
 
 =head1 DESCRIPTION
 
@@ -34,8 +35,19 @@ User feedback is an integral part of the evolution of this and other
 Bioperl modules. Send your comments and suggestions preferably to
 the Bioperl mailing list.  Your participation is much appreciated.
 
-  bioperl-l@bioperl.org              - General discussion
-  http://bioperl.org/MailList.shtml  - About the mailing lists
+  bioperl-l@bioperl.org                  - General discussion
+  http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
+
+=head2 Support
+
+Please direct usage questions or support issues to the mailing list:
+
+I<bioperl-l@bioperl.org>
+
+rather than to the module maintainer directly. Many experienced and
+reponsive experts will be able look at the problem and quickly
+address it. Please include a thorough description of the problem
+with code and data examples if at all possible.
 
 =head2 Reporting Bugs
 
@@ -43,11 +55,11 @@ Report bugs to the Bioperl bug tracking system to help us keep track
 of the bugs and their resolution. Bug reports can be submitted via the
 web:
 
-  http://bioperl.org/bioperl-bugs/
+  https://github.com/bioperl/bioperl-live/issues
 
 =head1 AUTHOR
 
-Martin Senger (senger@ebi.ac.uk)
+Martin Senger (martin.senger@gmail.com)
 
 =head1 COPYRIGHT
 
@@ -63,13 +75,7 @@ This software is provided "as is" without warranty of any kind.
 
 =head1 SEE ALSO
 
-=over
-
-=item *
-
-http://industry.ebi.ac.uk/soaplab/Perl_Client.html
-
-=back
+http://www.ebi.ac.uk/Tools/webservices/soaplab/guide
 
 =head1 APPENDIX
 
@@ -85,15 +91,10 @@ message. You need to call them on a C<Bio::Tools::Run::Analysis> object instead.
 # Let the code begin...
 
 package Bio::AnalysisI;
-use vars qw(@ISA  $Revision);
+$Bio::AnalysisI::VERSION = '1.7.8';
 use strict;
-use Bio::Root::RootI;
 
-@ISA = qw(Bio::Root::RootI);
-
-BEGIN {
-    $Revision = q[$Id: AnalysisI.pm,v 1.6 2004/11/16 17:45:38 jason Exp $];
-}
+use base qw(Bio::Root::RootI);
 
 # -----------------------------------------------------------------------------
 
@@ -121,7 +122,7 @@ C<supplier>, C<installation>, C<description>.
 
 Here is an example output:
 
-  Analysis 'edit::seqret':
+  Analysis 'edit.seqret':
         installation => EMBL-EBI
         description => Reads and writes (returns) sequences
         supplier => EMBOSS
@@ -180,7 +181,7 @@ The DTD used for returned metadata is based on the adopted standard
 
 But the DTD may be extended by provider-specific metadata. For
 example, the EBI experimental SOAP-based service on top of EMBOSS uses
-DTD explained at C<http://industry.ebi.ac.uk/applab>.
+DTD explained at C<http://www.ebi.ac.uk/~senger/applab>.
 
 =cut
 
@@ -197,8 +198,8 @@ sub describe { shift->throw_not_implemented(); }
 The analysis input data are named, and can be also associated with a
 default value, with allowed values and with few other attributes. The
 names are important for feeding the service with the input data (the
-inputs are given to methods C<create_job>, C<run>, and/or C<wait_for>
-as name/value pairs).
+inputs are given to methods C<create_job>, C<Bio::AnalysisI|run>, and/or
+C<Bio::AnalysisI|wait_for> as name/value pairs).
 
 Here is a (slightly shortened) example of an input specification:
 
@@ -297,7 +298,7 @@ The analysis results are named and can be retrieved using their names
 by methods C<results> and C<result>.
 
 Here is an example of the result specification (again for the service
-I<edit::seqret>):
+I<edit.seqret>):
 
   $result_spec = {
           'outseq' => 'String',
@@ -323,8 +324,8 @@ tool.
 
 Call this method if you wish to "stage the scene" - to create a job
 with all input data but without actually running it. This method is
-called automatically from other methods (C<run> and C<wait_for>) so
-usually you do not need to call it directly.
+called automatically from other methods (C<Bio::AnalysisI|run> and
+C<Bio::AnalysisI|wait_for>) so usually you do not need to call it directly.
 
 The input data and prameters for this execution can be specified in
 various ways:
@@ -416,7 +417,7 @@ sub wait_for { shift->throw_not_implemented(); }
 # -----------------------------------------------------------------------------
 
 package Bio::AnalysisI::JobI;
-
+$Bio::AnalysisI::JobI::VERSION = '1.7.8';
 =head1 Module Bio::AnalysisI::JobI
 
 An interface to the public methods provided by C<Bio::Tools::Run::Analysis::Job>
@@ -435,11 +436,8 @@ C<Bio::Tools::Run::Analysis::Job> object:
 
 =cut
 
-use vars qw(@ISA);
 use strict;
-use Bio::Root::RootI;
-
-@ISA = qw(Bio::Root::RootI);
+use base qw(Bio::Root::RootI);
 
 # -----------------------------------------------------------------------------
 
@@ -461,7 +459,7 @@ sub id { shift->throw_not_implemented(); }
 
 # -----------------------------------------------------------------------------
 
-=head2 run
+=head2 Bio::AnalysisI::JobI::run
 
  Usage   : $job->run
  Returns : itself
@@ -469,8 +467,8 @@ sub id { shift->throw_not_implemented(); }
 
 It starts previously created job.  The job already must have all input
 data filled-in. This differs from the method of the same name of the
-C<Bio::Tools::Run::Analysis> object where the C<run> method creates
-also a new job allowing to set input data.
+C<Bio::Tools::Run::Analysis> object where the C<Bio::AnalysisI::JobI::run> method
+creates also a new job allowing to set input data.
 
 =cut
 
@@ -478,7 +476,7 @@ sub run { shift->throw_not_implemented(); }
 
 # -----------------------------------------------------------------------------
 
-=head2 wait_for
+=head2 Bio::AnalysisI::JobI::wait_for
 
  Usage   : $job->wait_for
  Returns : itself
@@ -552,7 +550,7 @@ started, but before it finishes (note that the example uses an
 analysis 'showdb' which does not need any input data):
 
    use Bio::Tools::Run::Analysis;
-   print new Bio::Tools::Run::Analysis (-name => 'display::showdb')
+   print new Bio::Tools::Run::Analysis (-name => 'display.showdb')
              ->run
 	     ->last_event;
 
@@ -567,7 +565,7 @@ It prints:
 The same example but now after it finishes:
 
    use Bio::Tools::Run::Analysis;
-   print new Bio::Tools::Run::Analysis (-name => 'display::showdb')
+   print new Bio::Tools::Run::Analysis (-name => 'display.showdb')
              ->wait_for
 	     ->last_event;
 
@@ -668,10 +666,10 @@ sub elapsed { shift->throw_not_implemented(); }
 =head2 times
 
  Usage   : $job->times ('formatted')
- Returns : a hash refrence with all time characteristics
+ Returns : a hash reference with all time characteristics
  Args    : optional
 
-It is a convenient method returning a hash reference with the folowing
+It is a convenient method returning a hash reference with the following
 keys:
 
    created
@@ -679,17 +677,17 @@ keys:
    ended
    elapsed
 
-See C<create> for remarks on time formating.
+See C<create> for remarks on time formatting.
 
 An example - both for unformatted and formatted times:
 
    use Data::Dumper;
    use Bio::Tools::Run::Analysis;
-   my $rh = new Bio::Tools::Run::Analysis (-name => 'nucleic_cpg_islands::cpgplot')
+   my $rh = Bio::Tools::Run::Analysis->new(-name => 'nucleic_cpg_islands.cpgplot')
              ->wait_for ( { 'sequence_usa' => 'embl:hsu52852' } )
 	     ->times (1);
    print Data::Dumper->Dump ( [$rh], ['Times']);
-   $rh = new Bio::Tools::Run::Analysis (-name => 'nucleic_cpg_islands::cpgplot')
+   $rh = Bio::Tools::Run::Analysis->new(-name => 'nucleic_cpg_islands.cpgplot')
              ->wait_for ( { 'sequence_usa' => 'embl:AL499624' } )
 	     ->times;
    print Data::Dumper->Dump ( [$rh], ['Times']);
