@@ -1,4 +1,3 @@
-# $Id: AnnotationCollectionI.pm 16123 2009-09-17 12:57:27Z cjfields $
 #
 # BioPerl module for Bio::AnnotationCollectionI
 #
@@ -48,7 +47,7 @@ The Bioperl approach is that the "interesting facts" are represented by
 Bio::AnnotationI objects. The interface Bio::AnnotationI guarantees
 two methods
 
-   $obj->as_text(); # string formated to display to users
+   $obj->as_text(); # string formatted to display to users
 
 and
 
@@ -113,7 +112,7 @@ Report bugs to the Bioperl bug tracking system to help us keep track
 the bugs and their resolution.  Bug reports can be submitted via the
 web:
 
-  http://bugzilla.open-bio.org/
+  https://github.com/bioperl/bioperl-live/issues
 
 =head1 AUTHOR - Ewan Birney
 
@@ -130,6 +129,7 @@ are usually preceded with a _
 # Let the code begin...
 
 package Bio::AnnotationCollectionI;
+$Bio::AnnotationCollectionI::VERSION = '1.7.8';
 use strict;
 
 # Interface preamble - inherits from Bio::Root::RootI
