@@ -1,8 +1,7 @@
-# $Id: Blast.pm 16123 2009-09-17 12:57:27Z cjfields $
 #
 # BioPerl module for Bio::Index::Blast
 #
-# Please direct questions and support issues to <bioperl-l@bioperl.org> 
+# Please direct questions and support issues to <bioperl-l@bioperl.org>
 #
 # Cared for by Jason Stajich <jason@bioperl.org>
 #
@@ -14,7 +13,7 @@
 
 =head1 NAME
 
-Bio::Index::Blast - Indexes Blast reports and supports retrieval 
+Bio::Index::Blast - Indexes Blast reports and supports retrieval
 based on query accession(s)
 
 =head1 SYNOPSIS
@@ -53,7 +52,7 @@ This also allows for ID parsing using a callback:
    # here is where the retrieval key is specified
    sub get_id {
       my $line = shift;
-      $line =~ /^>.+gi\|(\d+)/;
+      $line =~ /^gi\|(\d+)/;
       $1;
    }
 
@@ -73,15 +72,15 @@ the Bioperl mailing list.  Your participation is much appreciated.
   bioperl-l@bioperl.org                  - General discussion
   http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
 
-=head2 Support 
+=head2 Support
 
 Please direct usage questions or support issues to the mailing list:
 
 I<bioperl-l@bioperl.org>
 
-rather than to the module maintainer directly. Many experienced and 
-reponsive experts will be able look at the problem and quickly 
-address it. Please include a thorough description of the problem 
+rather than to the module maintainer directly. Many experienced and
+reponsive experts will be able look at the problem and quickly
+address it. Please include a thorough description of the problem
 with code and data examples if at all possible.
 
 =head2 Reporting Bugs
@@ -90,7 +89,7 @@ Report bugs to the Bioperl bug tracking system to help us keep track
 of the bugs and their resolution. Bug reports can be submitted via the
 web:
 
-  http://bugzilla.open-bio.org/
+  https://github.com/bioperl/bioperl-live/issues
 
 =head1 AUTHOR - Jason Stajich
 
@@ -106,6 +105,7 @@ Internal methods are usually preceded with a _
 # Let the code begin...
 
 package Bio::Index::Blast;
+$Bio::Index::Blast::VERSION = '1.7.8';
 use strict;
 
 use IO::String;
@@ -113,7 +113,7 @@ use Bio::SearchIO;
 use base qw(Bio::Index::Abstract Bio::Root::Root);
 
 sub _version {
-	return ${Bio::Root::Version::VERSION};
+    return $Bio::Index::Blast::VERSION;
 }
 
 =head2 new
@@ -125,7 +125,7 @@ sub _version {
                 -verbose     => 0);
 
   Function: Returns a new index object.  If filename is
-            specified, then open_dbm() is immediately called. 
+            specified, then open_dbm() is immediately called.
             Bio::Index::Abstract->new() will usually be called
             directly only when opening an existing index.
   Returns : A new index object
@@ -140,11 +140,11 @@ sub _version {
 =cut
 
 sub new {
-
-  my($class,@args) = @_;
-
-  my $self = $class->SUPER::new(@args);
-
+    my($class,@args) = @_;
+    my $self = $class->SUPER::new(@args);
+    my ($type) = $self->_rearrange([qw(PARSER)], @args);
+    $type && $self->blast_parser_type($type);
+    $self;
 }
 
 =head2 Bio::Index::Blast implemented methods
@@ -155,7 +155,7 @@ sub new {
 
  Title   : fetch_report
  Usage   : my $blastreport = $idx->fetch_report($id);
- Function: Returns a Bio::SearchIO report object 
+ Function: Returns a Bio::SearchIO report object
            for a specific blast report
  Returns : Bio::SearchIO
  Args    : valid id
@@ -166,11 +166,24 @@ sub fetch_report{
 	my ($self,$id) = @_;
 	my $fh = $self->get_stream($id);
 	my $report = Bio::SearchIO->new(-noclose => 1,
-											 -format => 'blast',
-											 -fh => $fh);
+                                    -format => $self->blast_parser_type,
+                                    -fh => $fh);
 	return $report->next_result;
 }
 
+=head2 fetch_result
+
+ Title   : fetch_result
+ Usage   : my $blastreport = $idx->fetch_result($id);
+ Function: Returns a Bio::SearchIO report object
+           for a specific blast report
+ Returns : Bio::SearchIO
+ Args    : valid id
+ Note    : alias of fetch_report()
+
+=cut
+
+*fetch_result = \&fetch_report;
 
 =head2 Require methods from Bio::Index::Abstract
 
@@ -183,9 +196,9 @@ sub fetch_report{
   Function: Specialist function to index BLAST report file(s).
             Is provided with a filename and an integer
             by make_index in its SUPER class.
-  Example : 
-  Returns : 
-  Args    : 
+  Example :
+  Returns :
+  Args    :
 
 =cut
 
@@ -199,27 +212,37 @@ sub _index_file {
 		          # of the last found record.
 	  );
 
-	open(my $BLAST, '<', $file) or $self->throw("cannot open file $file\n");
+	open my $BLAST, '<', $file or $self->throw("Could not read file '$file': $!");
 
 	my (@data, @records);
 	my $indexpoint = 0;
 	my $lastline = 0;
 	my $prefix = '';
 
+	# In Windows, text files have '\r\n' as line separator, but when reading in
+	# text mode Perl will only show the '\n'. This means that for a line "ABC\r\n",
+	# "length $_" will report 4 although the line is 5 bytes in length.
+	# We assume that all lines have the same line separator and only read current line.
+	my $init_pos   = tell($BLAST);
+	my $curr_line  = <$BLAST>;
+	my $pos_diff   = tell($BLAST) - $init_pos;
+	my $correction = $pos_diff - length $curr_line;
+	seek $BLAST, $init_pos, 0; # Rewind position to proceed to read the file
+
 	# fencepost problem: we basically just find the top and the query
-	while( <$BLAST> ) {
-		
+	while( my $line = <$BLAST> ) {
+
 		# in recent RPS-BLAST output the only delimiter between result
 		# sections is '^Query=' - in other BLAST outputs you
 		# can use '^(RPS-|T?)BLAST(P?|N?|X?)'
 
-		if ( /^(RPS-|T?)BLAST(P?|N?|X?)/ ) {
+		if ( $line =~ /^(RPS-|T?)BLAST(P?|N?|X?)/ ) {
 			$prefix = $1;
-			$indexpoint = tell($BLAST) - length $_;
+			$indexpoint = tell($BLAST) - length($line) - $correction;
 		}
-		if ( /^Query=\s*([^\n]+)$/ ) {
+		if ( $line =~ /^Query=\s*([^\n]+)$/ ) {
 
-			$indexpoint = tell($BLAST) - length $_ if ( $prefix eq 'RPS-' );
+			$indexpoint = tell($BLAST) - length($line) - $correction if ( $prefix eq 'RPS-' );
 
 			foreach my $id ($self->id_parser()->($1)) {
 				$self->debug("id is $id, begin is $indexpoint\n");
@@ -238,7 +261,7 @@ sub _index_file {
   Function: Stores or returns the code used by record_id to
             parse the ID for record from a string.  Useful
             for (for instance) specifying a different
-            parser for different flavours of blast dbs. 
+            parser for different flavours of blast dbs.
             Returns \&default_id_parser (see below) if not
             set. If you supply your own id_parser
             subroutine, then it should expect a fasta
@@ -279,6 +302,32 @@ sub default_id_parser {
 	}
 }
 
+=head2 blast_parser_type
+
+  Title   : blast_parser_type
+  Usage   : $index->blast_parser_type() # returns
+  Function: Get/Set SearchIO-based text (-m0) BLAST parser. Only values in
+            local %VALID_PARSERS hash allowed.
+  Returns : String
+  Args    : [optional]
+  Note    : This only allows simple text-based parsing options; tabular, XML,
+            or others are not supported (see Bio::Index::BlastTable for tab
+            output).
+
+=cut
+
+my %VALID_PARSERS = map {$_ =>1} qw(blast blast_pull);
+
+sub blast_parser_type {
+    my ($self, $type) = @_;
+    if ($type) {
+        $self->throw("$type is not a supported BLAST text parser") unless
+            exists $VALID_PARSERS{$type};
+        $self->{_blast_parser_type} = $type;
+    }
+    return $self->{_blast_parser_type} || 'blast';
+}
+
 =head2 Bio::Index::Abstract methods
 
 =cut
@@ -299,7 +348,7 @@ sub default_id_parser {
  Usage   : $value = $self->write_flag();
            $self->write_flag($value);
  Function: Gets or sets the value of write_flag, which
-           is wether the dbm file should be opened with
+           is whether the dbm file should be opened with
            write access.
  Returns : The current value of write_flag (default 0)
  Args    : Value of write_flag if setting, or none if
@@ -310,11 +359,11 @@ sub default_id_parser {
  Usage   : $value = $self->dbm_package();
            $self->dbm_package($value);
 
- Function: Gets or sets the name of the Perl dbm module used. 
+ Function: Gets or sets the name of the Perl dbm module used.
            If the value is unset, then it returns the value of
            the package variable $USE_DBM_TYPE or if that is
            unset, then it chooses the best available dbm type,
-           choosing 'DB_File' in preference to 'SDBM_File'. 
+           choosing 'DB_File' in preference to 'SDBM_File'.
            Bio::Abstract::Index may work with other dbm file
            types.
 
@@ -331,10 +380,10 @@ sub default_id_parser {
            at the approprite place
 
            This provides for a way to get the actual
-           file contents and not an object 
+           file contents and not an object
 
            WARNING: you must parse the record deliminter
-           *yourself*. Abstract wont do this for you 
+           *yourself*. Abstract won't do this for you
            So this code
 
            $fh = $index->get_stream($myid);
@@ -351,7 +400,7 @@ sub default_id_parser {
 
  Returns : A filehandle object
  Args    : string represents the accession number
- Notes   : This method should not be used without forethought 
+ Notes   : This method should not be used without forethought
 
 
 =head2 open_dbm
@@ -361,7 +410,7 @@ sub default_id_parser {
             object.  Write access is only given if explicitly
             asked for by calling new(-write => 1) or having set
             the write_flag(1) on the index object.  The type of
-            dbm file opened is that returned by dbm_package(). 
+            dbm file opened is that returned by dbm_package().
             The name of the file to be is opened is obtained by
             calling the filename() method.
 
@@ -377,8 +426,8 @@ sub default_id_parser {
             index module.  Used to permanently identify an index
             file as having been created by a particular version
             of the index module.  Must be provided by the sub class
-  Example : 
-  Returns : 
+  Example :
+  Returns :
   Args    : none
 
 =head2 _filename
@@ -386,9 +435,9 @@ sub default_id_parser {
   Title   : _filename
   Usage   : $index->_filename( FILE INT )
   Function: Indexes the file
-  Example : 
-  Returns : 
-  Args    : 
+  Example :
+  Returns :
+  Args    :
 
 =head2 _file_handle
 
@@ -411,7 +460,7 @@ sub default_id_parser {
             track the number of files indexed.  Sets or gets
             the number of files indexed when called with or
             without an argument.
-  Example : 
+  Example :
   Returns : INT
   Args    : INT
 
@@ -435,7 +484,7 @@ sub default_id_parser {
   Usage   : $packed_string = $index->pack_record( LIST )
   Function: Packs an array of scalars into a single string
             joined by ASCII 034 (which is unlikely to be used
-            in any of the strings), and returns it. 
+            in any of the strings), and returns it.
   Example : $packed_string = $index->pack_record( $fileNumber, $begin, $end )
   Returns : STRING or undef
   Args    : LIST
