@@ -1,5 +1,4 @@
 #
-# $Id: Qual.pm 16123 2009-09-17 12:57:27Z cjfields $
 #
 # BioPerl module for Bio::Index::Qual
 #
@@ -47,14 +46,13 @@ Bio::Index::Qual - Interface for indexing (multiple) fasta qual files
 =head1 DESCRIPTION
 
 Inherits functions for managing dbm files from Bio::Index::Abstract.pm,
-and provides the basic funtionallity for indexing qual files, and
+and provides the basic funtionality for indexing qual files, and
 retrieving the sequence from them. For best results 'use strict'.
 
 Bio::Index::Qual supports the Bio::DB::BioSeqI interface, meaning
 it can be used as a Sequence database for other parts of bioperl
 
-Additional example code is available in scripts/index/*PLS and in 
-the Bioperl Tutorial (L<http://www.bioperl.org/wiki/Bptutorial.pl>).
+Additional example code is available in scripts/index.
 
 Note that by default the key for the sequence will be the first continuous
 string after the 'E<gt>' in the qual header. If you want to use a specific
@@ -103,11 +101,11 @@ Report bugs to the Bioperl bug tracking system to help us keep track
 the bugs and their resolution.  Bug reports can be submitted via the
 web:
 
-  http://bugzilla.open-bio.org/
+  https://github.com/bioperl/bioperl-live/issues
 
 =head1 AUTHOR - James Gilbert, Mark Johnson
 
-Email - jgrg@sanger.ac.uk, mjohnson@watson.wustl.edu
+Email - jgrg@sanger.ac.uk, johnsonm-at-gmail-dot-com 
 
 =head1 APPENDIX
 
@@ -120,7 +118,7 @@ The rest of the documentation details each of the object methods. Internal metho
 
 
 package Bio::Index::Qual;
-
+$Bio::Index::Qual::VERSION = '1.7.8';
 use strict;
 
 use Bio::Seq;
@@ -179,14 +177,22 @@ sub _index_file {
 
 	my $id_parser = $self->id_parser;
 
-	open my $QUAL, '<', $file or $self->throw("Can't open file for read : $file");
+	open my $QUAL, '<', $file or $self->throw("Could not read file '$file': $!");
+
+	# In Windows, text files have '\r\n' as line separator, but when reading in
+	# text mode Perl will only show the '\n'. This means that for a line "ABC\r\n",
+	# "length $_" will report 4 although the line is 5 bytes in length.
+	# We assume that all lines have the same line separator and only read current line.
+	my $init_pos   = tell($QUAL);
+	my $curr_line  = <$QUAL>;
+	my $pos_diff   = tell($QUAL) - $init_pos;
+	my $correction = $pos_diff - length $curr_line;
+	seek $QUAL, $init_pos, 0; # Rewind position to proceed to read the file
 
 	# Main indexing loop
 	while (<$QUAL>) {
 		if (/^>/) {
-			# $begin is the position of the first character after the '>'
-                        my $offset = ( $^O =~ /mswin/i ) ? 0 : 1;
-			my $begin = tell($QUAL) - length( $_ ) + $offset;
+			my $begin = tell($QUAL) - length( $_ ) + 1 - $correction;
 
 			foreach my $id (&$id_parser($_)) {
 				$self->add_record($id, $i, $begin);
