@@ -1,4 +1,3 @@
-# $Id: Swissprot.pm 16123 2009-09-17 12:57:27Z cjfields $
 #
 # BioPerl module for Bio::Index::Swissprot
 #
@@ -97,7 +96,7 @@ Report bugs to the Bioperl bug tracking system to help us keep track
 the bugs and their resolution.  Bug reports can be submitted via
 the web:
 
-  http://bugzilla.open-bio.org/
+  https://github.com/bioperl/bioperl-live/issues
 
 =head1 AUTHOR - Ewan Birney
 
@@ -113,7 +112,7 @@ Internal methods are usually preceded with a _
 # Let's begin the code...
 
 package Bio::Index::Swissprot;
-
+$Bio::Index::Swissprot::VERSION = '1.7.8';
 use strict;
 
 use Bio::Seq;
@@ -150,12 +149,23 @@ sub _index_file {
 
 	my $id_parser = $self->id_parser;
 
-	open my $SWISSPROT,'<',$file or $self->throw("Can't read file: $file");
+	open my $SWISSPROT, '<', $file or $self->throw("Could not read file '$file': $!");
     
         my %done_ids;
+
+	# In Windows, text files have '\r\n' as line separator, but when reading in
+	# text mode Perl will only show the '\n'. This means that for a line "ABC\r\n",
+	# "length $_" will report 4 although the line is 5 bytes in length.
+	# We assume that all lines have the same line separator and only read current line.
+	my $init_pos   = tell($SWISSPROT);
+	my $curr_line  = <$SWISSPROT>;
+	my $pos_diff   = tell($SWISSPROT) - $init_pos;
+	my $correction = $pos_diff - length $curr_line;
+	seek $SWISSPROT, $init_pos, 0; # Rewind position to proceed to read the file
+
 	while (<$SWISSPROT>) {
 		if (/^ID\s+\S+/) {
-			$begin = tell($SWISSPROT) - length( $_ );
+			$begin = tell($SWISSPROT) - length( $_ ) - $correction;
 		}
 		for my $id (&$id_parser($_)) {
                         next if exists $done_ids{$id};
