@@ -1,4 +1,3 @@
-# $Id: PullHSPI.pm 16123 2009-09-17 12:57:27Z cjfields $
 #
 # BioPerl module for Bio::Search::HSP::PullHSPI
 #
@@ -98,7 +97,7 @@ Report bugs to the Bioperl bug tracking system to help us keep track
 of the bugs and their resolution. Bug reports can be submitted via the
 web:
 
-  http://bugzilla.open-bio.org/
+  https://github.com/bioperl/bioperl-live/issues
 
 =head1 AUTHOR - Sendu Bala
 
@@ -122,7 +121,7 @@ Internal methods are usually preceded with a _
 # Let the code begin...
 
 package Bio::Search::HSP::PullHSPI;
-
+$Bio::Search::HSP::PullHSPI::VERSION = '1.7.8';
 
 use strict;
 
@@ -652,7 +651,7 @@ sub bits {
  Returns : +1 or -1 (0 if unknown)
  Args    : 'hit' or 'subject' or 'sbjct' to retrieve the strand of the subject
            'query' to retrieve the query strand (default)
-           'list' or 'array' to retreive both query and hit together
+           'list' or 'array' to retrieve both query and hit together
 
 =cut
 
