@@ -1,7 +1,8 @@
-# $Id: GenericResult.pm,v 1.18 2004/05/14 17:06:48 matsallac Exp $
 #
 # BioPerl module for Bio::Search::Result::GenericResult
 #
+# Please direct questions and support issues to <bioperl-l@bioperl.org> 
+#
 # Cared for by Jason Stajich <jason@bioperl.org>
 #
 # Copyright Jason Stajich
@@ -12,26 +13,28 @@
 
 =head1 NAME
 
-Bio::Search::Result::GenericResult - Generic Implementation of Bio::Search::Result::ResultI interface applicable to most search results.
+Bio::Search::Result::GenericResult - Generic Implementation of
+Bio::Search::Result::ResultI interface applicable to most search
+results.
 
 =head1 SYNOPSIS
 
 
     # typically one gets Results from a SearchIO stream
     use Bio::SearchIO;
-    my $io = new Bio::SearchIO(-format => 'blast',
+    my $io = Bio::SearchIO->new(-format => 'blast',
                                 -file   => 't/data/HUMBETGLOA.tblastx');
-    while( my $result = $io->next_result) {
+    while( my $result = $io->next_result ) {
         # process all search results within the input stream
-        while( my $hit = $result->next_hits()) {  
-        # insert code here for hit processing
+        while( my $hit = $result->next_hit ) {  
+            # insert code here for hit processing
         }
     }
 
     use Bio::Search::Result::GenericResult;
     my @hits = (); # would be a list of Bio::Search::Hit::HitI objects
     # typically these are created from a Bio::SearchIO stream
-    my $result = new Bio::Search::Result::GenericResult
+    my $result = Bio::Search::Result::GenericResult->new
         ( -query_name        => 'HUMBETGLOA',
           -query_accession   => ''
           -query_description => 'Human haplotype C4 beta-globin gene, complete cds.'
@@ -90,17 +93,27 @@ User feedback is an integral part of the evolution of this and other
 Bioperl modules. Send your comments and suggestions preferably to
 the Bioperl mailing list.  Your participation is much appreciated.
 
-  bioperl-l@bioperl.org              - General discussion
-  http://bioperl.org/MailList.shtml  - About the mailing lists
+  bioperl-l@bioperl.org                  - General discussion
+  http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
+
+=head2 Support 
+
+Please direct usage questions or support issues to the mailing list:
+
+I<bioperl-l@bioperl.org>
+
+rather than to the module maintainer directly. Many experienced and 
+reponsive experts will be able look at the problem and quickly 
+address it. Please include a thorough description of the problem 
+with code and data examples if at all possible.
 
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
-of the bugs and their resolution. Bug reports can be submitted via
-email or the web:
+of the bugs and their resolution. Bug reports can be submitted via the
+web:
 
-  bioperl-bugs@bioperl.org
-  http://bugzilla.bioperl.org/
+  https://github.com/bioperl/bioperl-live/issues
 
 =head1 AUTHOR - Jason Stajich and Steve Chervitz
 
@@ -109,7 +122,7 @@ Email sac@bioperl.org
 
 =head1 CONTRIBUTORS
 
-Additional contributors names and emails here
+Sendu Bala, bix@sendu.me.uk
 
 =head1 APPENDIX
 
@@ -123,11 +136,9 @@ Internal methods are usually preceded with a _
 
 
 package Bio::Search::Result::GenericResult;
-use vars qw(@ISA);
+$Bio::Search::Result::GenericResult::VERSION = '1.7.8';
 use strict;
 
-use Bio::Root::Root;
-use Bio::Search::Result::ResultI;
 use Bio::Search::GenericStatistics;
 use Bio::Tools::Run::GenericParameters;
 
@@ -135,12 +146,12 @@ use Bio::Tools::Run::GenericParameters;
 #use overload 
 #    '""' => \&to_string;
 
-@ISA = qw(Bio::Root::Root Bio::Search::Result::ResultI);
+use base qw(Bio::Root::Root Bio::Search::Result::ResultI);
 
 =head2 new
 
  Title   : new
- Usage   : my $obj = new Bio::Search::Result::GenericResult();
+ Usage   : my $obj = Bio::Search::Result::GenericResult->new();
  Function: Builds a new Bio::Search::Result::GenericResult object 
  Returns : Bio::Search::Result::GenericResult
  Args    : -query_name        => Name of query Sequence
@@ -156,6 +167,9 @@ use Bio::Tools::Run::GenericParameters;
            -algorithm         => program name (blastx)
            -algorithm_version   => version of the algorithm (2.1.2)
            -algorithm_reference => literature reference string for this algorithm
+           -rid               => value of the BLAST Request ID (eg. RID: ZABJ4EA7014)
+           -hit_factory       => Bio::Factory::ObjectFactoryI capable of making
+                                 Bio::Search::Hit::HitI objects
 
 =cut
 
@@ -166,16 +180,17 @@ sub new {
 
   $self->{'_hits'} = [];
   $self->{'_hitindex'} = 0;
-  $self->{'_statistics'} = new Bio::Search::GenericStatistics;
-  $self->{'_parameters'} = new Bio::Tools::Run::GenericParameters;
+  $self->{'_statistics'} = Bio::Search::GenericStatistics->new();
+  $self->{'_parameters'} = Bio::Tools::Run::GenericParameters->new();
 
-  my ($qname,$qacc,$qdesc,$qlen,
+  my ($qname,$qacc,$qdesc,$qlen, $qgi,
       $dbname,$dblet,$dbent,$params,   
       $stats, $hits, $algo, $algo_v,
-      $prog_ref, $algo_r) = $self->_rearrange([qw(QUERY_NAME
+      $prog_ref, $algo_r, $rid, $hit_factory) = $self->_rearrange([qw(QUERY_NAME
                                                   QUERY_ACCESSION
                                                   QUERY_DESCRIPTION
                                                   QUERY_LENGTH
+                                                  QUERY_GI
                                                   DATABASE_NAME
                                                   DATABASE_LETTERS
                                                   DATABASE_ENTRIES
@@ -186,6 +201,8 @@ sub new {
                                                   ALGORITHM_VERSION
                                                   PROGRAM_REFERENCE
                                                   ALGORITHM_REFERENCE
+                                                  RID
+                                                  HIT_FACTORY
                                                  )],@args);
 
   $algo_r ||= $prog_ref;         
@@ -193,17 +210,22 @@ sub new {
   defined $algo_v && $self->algorithm_version($algo_v);
   defined $algo_r && $self->algorithm_reference($algo_r);
 
+  defined $rid && $self->rid($rid);
+
   defined $qname && $self->query_name($qname);
   defined $qacc  && $self->query_accession($qacc);
   defined $qdesc && $self->query_description($qdesc);
   defined $qlen  && $self->query_length($qlen);
+  defined $qgi   && $self->query_gi($qgi);
   defined $dbname && $self->database_name($dbname);
   defined $dblet  && $self->database_letters($dblet);
   defined $dbent  && $self->database_entries($dbent);
 
+  defined $hit_factory && $self->hit_factory($hit_factory);
+  
   if( defined $params ) {
       if( ref($params) !~ /hash/i ) {
-          $self->throw("Must specify a hash reference with the the parameter '-parameters");
+          $self->throw("Must specify a hash reference with the parameter '-parameters");
       }
       while( my ($key,$value) = each %{$params} ) {
           $self->{'_parameters'}->set_parameter($key   =>   $value);
@@ -212,7 +234,7 @@ sub new {
   }
   if( defined $stats ) {
       if( ref($stats) !~ /hash/i ) {
-          $self->throw("Must specify a hash reference with the the parameter '-statistics");
+          $self->throw("Must specify a hash reference with the parameter '-statistics");
       }
       while( my ($key,$value) = each %{$stats} ) {
           $self->{'_statistics'}->set_statistic($key   =>   $value); 
@@ -290,8 +312,16 @@ Bio::Search::Result::ResultI implementation
 sub next_hit {
     my ($self,@args) = @_;
     my $index = $self->_nexthitindex;
-    return undef if $index > scalar @{$self->{'_hits'}};
-    return $self->{'_hits'}->[$index];    
+    return if $index > scalar @{$self->{'_hits'}};
+    
+    my $hit = $self->{'_hits'}->[$index];
+    if (ref($hit) eq 'HASH') {
+        my $factory = $self->hit_factory || $self->throw("Tried to get a Hit, but it was a hash ref and we have no hit factory");
+        $hit = $factory->create_object(%{$hit});
+        $self->{'_hits'}->[$index] = $hit;
+        delete $self->{_hashes}->{$index};
+    }
+    return $hit;    
 }
 
 =head2 query_name
@@ -335,6 +365,27 @@ sub query_accession {
     return $previous;
 }
 
+=head2 query_gi
+
+ Title   : query_gi
+ Usage   : $acc = $hit->query_gi();
+ Function: Retrieve the NCBI Unique ID (aka the GI #),
+           if available, for the query
+ Returns : a scalar string (empty string if not set)
+ Args    : none
+
+=cut
+
+sub query_gi {
+    my ($self,$value) = @_;
+    if( defined $value ) {
+        $self->{'_query_gi'} = $value;
+    } else {
+        $self->{'_query_gi'} = $self->query_name =~ m{^gi\|(\d+)} ? $1 : '';
+    } 
+    return $self->{'_query_gi'};
+}
+
 =head2 query_length
 
  Title   : query_length
@@ -455,9 +506,9 @@ sub database_entries {
 
 =cut
 
-sub get_parameter{
+sub get_parameter {
    my ($self,$name) = @_;
-   return $self->{'_parameters'}->{$name};
+   return $self->{'_parameters'}->get_parameter($name);
 }
 
 =head2 available_parameters
@@ -472,7 +523,7 @@ sub get_parameter{
 
 sub available_parameters{
    my ($self) = @_;
-   return keys %{$self->{'_parameters'}};
+   return $self->{'_parameters'}->available_parameters;
 }
 
 
@@ -489,7 +540,7 @@ sub available_parameters{
 
 sub get_statistic{
    my ($self,$key) = @_;
-   return $self->{'_statistics'}->{$key};
+   return $self->{'_statistics'}->get_statistic($key);
 }
 
 =head2 available_statistics
@@ -504,7 +555,7 @@ sub get_statistic{
 
 sub available_statistics{
    my ($self) = @_;
-   return keys %{$self->{'_statistics'}};
+   return $self->{'_statistics'}->available_statistics;
 }
 
 =head2 Bio::Search::Report 
@@ -523,15 +574,34 @@ Bio::Search::Result::GenericResult specific methods
 
 sub add_hit {
     my ($self,$s) = @_;
-    if( $s->isa('Bio::Search::Hit::HitI') ) { 
+    if (ref($s) eq 'HASH' || $s->isa('Bio::Search::Hit::HitI') ) {
         push @{$self->{'_hits'}}, $s;
-    } else { 
-        $self->throw("Passed in " .ref($s). 
-                     " as a Hit which is not a Bio::Search::HitI.");
+    }
+    else { 
+        $self->throw("Passed in " .ref($s)." as a Hit which is not a Bio::Search::HitI.");
+    }
+    
+    if (ref($s) eq 'HASH') {
+        $self->{_hashes}->{$#{$self->{'_hits'}}} = 1;
     }
     return scalar @{$self->{'_hits'}};
 }
 
+=head2 hit_factory
+
+ Title   : hit_factory
+ Usage   : $hit->hit_factory($hit_factory)
+ Function: Get/set the factory used to build HitI objects if necessary.
+ Returns : Bio::Factory::ObjectFactoryI
+ Args    : Bio::Factory::ObjectFactoryI
+
+=cut
+
+sub hit_factory {
+    my $self = shift;
+    if (@_) { $self->{_hit_factory} = shift }
+    return $self->{_hit_factory} || return;
+}
 
 =head2 rewind
 
@@ -593,7 +663,7 @@ sub add_parameter {
 
 sub add_statistic {
    my ($self,$key,$value) = @_;
-   $self->{'_statistics'}->{$key} = $value;
+   $self->{'_statistics'}->set_statistic($key => $value);
    return;
 }
 
@@ -606,7 +676,6 @@ sub add_statistic {
  Returns : integer
  Args    : none
 
-
 =cut
 
 sub num_hits{
@@ -629,12 +698,19 @@ sub num_hits{
 
 =cut
 
-sub hits{
-   my ($self) = shift;
-   my @hits = ();
-   if( ref $self->{'_hits'}) {
-       @hits = @{$self->{'_hits'}};
-   }
+sub hits {
+    my ($self) = shift;
+    
+    foreach my $i (keys %{$self->{_hashes} || {}}) {
+        my $factory = $self->hit_factory || $self->throw("Tried to get a Hit, but it was a hash ref and we have no hit factory");
+        $self->{'_hits'}->[$i] = $factory->create_object(%{$self->{'_hits'}->[$i]});
+        delete $self->{_hashes}->{$i};
+    }
+    
+    my @hits = ();
+    if (ref $self->{'_hits'}) {
+        @hits = @{$self->{'_hits'}};
+    }
     return @hits;   
 }
 
@@ -658,10 +734,41 @@ sub algorithm_reference{
     return $self->{'algorithm_reference'};
 }
 
+=head2 program_reference
+
+ Title   : program_reference
+ Usage   : $obj->program_reference()
+ Function:
+ Returns : string containing literature reference for the algorithm
+ Args    : 
+ Comments: Deprecated - use algorithm_reference() instead.
+
+=cut
 
 sub program_reference { shift->algorithm_reference(@_); }
 
+=head2 rid
 
+ Title   : rid
+ Usage   : $obj->rid($newval)
+ Function:
+ Returns : value of the BLAST Request ID (eg. RID: ZABJ4EA7014)
+ Args    : newvalue (optional)
+ Comments: The default implementation in ResultI returns an empty string
+           rather than throwing a NotImplemented exception, since
+           the RID may not always be available and is not critical.
+           See: (1) https://www.ncbi.nlm.nih.gov/Class/MLACourse/Modules/BLAST/rid.html
+                (2) https://www.ncbi.nlm.nih.gov/staff/tao/URLAPI/new/node63.html
+=cut
+
+sub rid{
+    my ($self,$value) = @_;
+    if( defined $value) {
+	   $self->{'rid'} = $value;
+	}
+	return $self->{'rid'};
+}
+	
 =head2 no_hits_found
 
 See documentation in L<Bio::Search::Result::ResultI::no_hits_found()|Bio::Search::Result::ResultI>
