@@ -1,4 +1,3 @@
-# $Id: axt.pm 16123 2009-09-17 12:57:27Z cjfields $
 #
 # BioPerl module for Bio::SearchIO::axt
 #
@@ -65,7 +64,7 @@ Report bugs to the Bioperl bug tracking system to help us keep track
 of the bugs and their resolution. Bug reports can be submitted via the
 web:
 
-  http://bugzilla.open-bio.org/
+  https://github.com/bioperl/bioperl-live/issues
 
 =head1 AUTHOR - Jason Stajich
 
@@ -83,6 +82,7 @@ Internal methods are usually preceded with a _
 
 
 package Bio::SearchIO::axt;
+$Bio::SearchIO::axt::VERSION = '1.7.8';
 use vars qw(%MODEMAP %MAPPING @STATES $GAPCHAR);
 use strict;
 
@@ -171,13 +171,13 @@ sub next_result{
 						   $6,$7,$8,$9);
 	    $self->{'_reporttype'} = 'AXT';
 	    # Jim's code is 0 based
-	    $qstart++;  $qend++; $hstart++; $hend++;
-	    if( defined $curquery && 
-		$curquery ne $qname ) { 
-		$self->end_element({'Name' => 'Hit'});
-		$self->_pushback($_);
-		$self->end_element({'Name' => 'AXTOutput'});
-		return $self->end_document();
+        # yes, but axt format is one-based, see bug 3145 - cjfields 10-11-10
+	    #$qstart++;  $qend++; $hstart++; $hend++;
+	    if( defined $curquery &&  $curquery ne $qname ) { 
+            $self->end_element({'Name' => 'Hit'});
+            $self->_pushback($_);
+            $self->end_element({'Name' => 'AXTOutput'});
+            return $self->end_document();
 	    }
 	    
 	    if( defined $curhit &&
