@@ -1,7 +1,8 @@
-# $Id $
 #
 # BioPerl module for Bio::SearchIO::sim4
 #
+# Please direct questions and support issues to <bioperl-l@bioperl.org> 
+#
 # Cared for by Jason Stajich <jason-at-bioperl-dot-org>
 #
 # Copyright Jason Stajich
@@ -18,7 +19,7 @@ Bio::SearchIO::sim4 - parser for Sim4 alignments
 
   # do not use this module directly, it is a driver for SearchIO
   use Bio::SearchIO;
-  my $searchio = new Bio::SearchIO(-file => 'results.sim4',
+  my $searchio = Bio::SearchIO->new(-file => 'results.sim4',
                                    -format => 'sim4');
 
   while ( my $result = $searchio->next_result ) {
@@ -44,17 +45,27 @@ User feedback is an integral part of the evolution of this and other
 Bioperl modules. Send your comments and suggestions preferably to
 the Bioperl mailing list.  Your participation is much appreciated.
 
-  bioperl-l@bioperl.org              - General discussion
-  http://bioperl.org/MailList.shtml  - About the mailing lists
+  bioperl-l@bioperl.org                  - General discussion
+  http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
+
+=head2 Support 
+
+Please direct usage questions or support issues to the mailing list:
+
+I<bioperl-l@bioperl.org>
+
+rather than to the module maintainer directly. Many experienced and 
+reponsive experts will be able look at the problem and quickly 
+address it. Please include a thorough description of the problem 
+with code and data examples if at all possible.
 
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
-of the bugs and their resolution. Bug reports can be submitted via
-email or the web:
+of the bugs and their resolution. Bug reports can be submitted via the
+web:
 
-  bioperl-bugs@bioperl.org
-  http://bioperl.org/bioperl-bugs/
+  https://github.com/bioperl/bioperl-live/issues
 
 =head1 AUTHOR - Jason Stajich
 
@@ -76,19 +87,18 @@ Internal methods are usually preceded with a _
 
 
 package Bio::SearchIO::sim4;
-
+$Bio::SearchIO::sim4::VERSION = '1.7.8';
 use strict;
-use vars qw(@ISA $DEFAULTFORMAT %ALIGN_TYPES
+use vars qw($DEFAULTFORMAT %ALIGN_TYPES
             %MAPPING %MODEMAP $DEFAULT_WRITER_CLASS);
 
 use POSIX;
-use Bio::SearchIO;
 use Bio::SearchIO::SearchResultEventBuilder;
 
-@ISA = qw(Bio::SearchIO );
+use base qw(Bio::SearchIO);
 
 $DEFAULTFORMAT = 'SIM4';
-$DEFAULT_WRITER_CLASS = 'Bio::Search::Writer::HitTableWriter';
+$DEFAULT_WRITER_CLASS = 'Bio::SearchIO::Writer::HitTableWriter';
 
 %ALIGN_TYPES = (
     0 => 'Ruler',
@@ -134,7 +144,7 @@ $DEFAULT_WRITER_CLASS = 'Bio::Search::Writer::HitTableWriter';
 =head2 new
 
  Title   : new
- Usage   : my $obj = new Bio::SearchIO::sim4();
+ Usage   : my $obj = Bio::SearchIO::sim4->new();
  Function: Builds a new Bio::SearchIO::sim4 object
  Returns : an instance of Bio::SearchIO::sim4
  Args    :
@@ -155,6 +165,8 @@ $DEFAULT_WRITER_CLASS = 'Bio::Search::Writer::HitTableWriter';
 
 sub next_result {
     my ($self) = @_;
+    local $/ = "\n";
+    local $_;
 
     # Declare/adjust needed variables
     $self->{'_last_data'} = '';
@@ -369,7 +381,7 @@ sub next_result {
 	$self->end_element({'Name' => 'Sim4Output'});
 	return $self->end_document();
     } 
-    return undef;
+    return;
 }
 
 =head2 start_element
