@@ -1,4 +1,3 @@
-# $Id: wise.pm 16123 2009-09-17 12:57:27Z cjfields $
 #
 # BioPerl module for Bio::SearchIO::wise
 #
@@ -58,7 +57,7 @@ Report bugs to the Bioperl bug tracking system to help us keep track
 of the bugs and their resolution. Bug reports can be submitted via
 the web:
 
-  http://bugzilla.open-bio.org/
+  https://github.com/bioperl/bioperl-live/issues
 
 =head1 AUTHOR - Jason Stajich
 
@@ -76,6 +75,7 @@ Internal methods are usually preceded with a _
 
 
 package Bio::SearchIO::wise;
+$Bio::SearchIO::wise::VERSION = '1.7.8';
 use vars qw(%MAPPING %MODEMAP $DEFAULT_WRITER_CLASS);
 use strict;
 
@@ -117,7 +117,7 @@ use base qw(Bio::SearchIO);
      'WiseOutput_query-len' => 'RESULT-query_length',
     );
 
-$DEFAULT_WRITER_CLASS = 'Bio::Search::Writer::HitTableWriter';
+$DEFAULT_WRITER_CLASS = 'Bio::SearchIO::Writer::HitTableWriter';
 
 
 use Bio::Tools::Genewise;
