@@ -89,7 +89,7 @@ associated Bio::AnnotationCollectionI object which is associated with
 Bio::Seq objects.  If it is explicitly requested that no annotations
 should be stored when parsing a record of course they will not be
 available when you try and get them.  If you are having this problem
-look at the type of SeqBuilder that is being used to contruct your
+look at the type of SeqBuilder that is being used to construct your
 sequence object.
 
  Comments             Annotation 'comment'
@@ -117,7 +117,7 @@ sequence object.
 
 There is more information in the Feature-Annotation HOWTO about each
 field and how it is mapped to the Sequence object
-L<http://bioperl.open-bio.org/wiki/HOWTO:Feature-Annotation>.
+L<http://bioperl.org/howtos/Features_and_Annotations_HOWTO.html>.
 
 =head1 FEEDBACK
 
@@ -177,6 +177,7 @@ methods. Internal methods are usually preceded with a _
 # Let the code begin...
 
 package Bio::SeqIO::genbank;
+$Bio::SeqIO::genbank::VERSION = '1.7.8';
 use strict;
 
 use Bio::SeqIO::FTHelper;
@@ -190,18 +191,17 @@ use Bio::Annotation::DBLink;
 
 use base qw(Bio::SeqIO);
 
-# Note that a qualifier that exceeds one line (i.e. a long label) will
-# automatically be quoted regardless:
-
 our $FTQUAL_LINE_LENGTH = 60;
 
 our %FTQUAL_NO_QUOTE = map {$_ => 1} qw(
     anticodon           citation
     codon               codon_start
-    cons_splice         direction
+    compare             cons_splice
+    direction           estimated_length
     evidence            label
     mod_base            number
     rpt_type            rpt_unit
+    rpt_unit_range      tag_peptide
     transl_except       transl_table
     usedin
     );
@@ -499,7 +499,9 @@ sub next_seq {
                 }
             }
 
-            # Comments
+            # Comments may be plain text or Structured Comments.
+            # Structured Comments are made up of tag/value pairs and have beginning
+            # and end delimiters like ##*-Data-START## and ##*-Data-END##
             elsif ($line =~ /^COMMENT\s+(\S.*)/) {
                 if ($annotation) {
                     my $comment = $1;
@@ -507,8 +509,20 @@ sub next_seq {
                         last if ($line =~ /^\S/);
                         $comment .= $line;
                     }
-                    $comment =~ s/\n/ /g;
                     $comment =~ s/  +/ /g;
+                    # Structured Comment, do not remove returns in the tabular section
+                    if ( my ( $text, $table )= $comment
+                        =~ /([^#]*)(##\S+Data-START##.+?##\S+Data-END##)/is
+                        ) {
+                        $text    =~ s/\n/ /g if $text;
+                        $table   =~ s/START##/START##\n/;
+                        $table   =~ s/^\s+//gm;
+                        $comment = $text . "\n" . $table;
+                    }
+                    # Plain text, remove returns
+                    else {
+                        $comment =~ s/\n/ /g;
+                    }
                     $annotation->add_Annotation(
                         'comment',
                         Bio::Annotation::Comment->new(
@@ -951,7 +965,7 @@ sub write_seq {
 
         my $circular = ($seq->is_circular) ? 'circular' : 'linear  ';
 
-        local($^W) = 0; # supressing warnings about uninitialized fields.
+        local($^W) = 0; # suppressing warnings about uninitialized fields.
 
         my $temp_line;
         if ( $self->_id_generation_func ) {
@@ -1179,7 +1193,6 @@ sub write_seq {
                 $self->_print($cline);
                 $ct++;
             }
-            $self->_show_dna(0);
         }
         if ( $seq->length == 0 ) {
             $self->_show_dna(0);
@@ -1260,7 +1273,7 @@ sub _print_GenBank_FTHelper {
         sprintf( "     %-16s%s", $fth->key, $spacer ),
                  " " x 21, $fth->loc, "\,\|\$", 80 );
 
-    foreach my $tag ( keys %{ $fth->field } ) {
+    foreach my $tag ( sort keys %{ $fth->field } ) {
         # Account for hash structure in Annotation::DBLink, not the expected array
         if ( $tag eq 'db_xref' and grep /HASH/, @{ $fth->field->{$tag} }) {
             for my $ref ( @{ $fth->field->{$tag} } ) {
@@ -1284,18 +1297,27 @@ sub _print_GenBank_FTHelper {
                # There are almost 3x more quoted qualifier values and they
                # are more common too so we take quoted ones first.
                # Long qualifiers, that will be line wrapped, are always quoted
-                elsif (   not $FTQUAL_NO_QUOTE{$tag}
-                       or length("/$tag=$value") >= $FTQUAL_LINE_LENGTH
-                    ) {
-                    my ($pat) = ( $value =~ /\s/ ? '\s|$' : '.|$' );
+
+               # Note (cjf): any tags explicitly *not* quoted must
+               # remain unquoted in all output for proper round trip
+               # parsing:
+               # see https://github.com/bioperl/bioperl-live/issues/321
+
+               # If this breaks *NCBI* examples please file an issue with
+               # example files
+                elsif (   not $FTQUAL_NO_QUOTE{$tag} ) {
+                    my ($pat) = ( $value =~ /\s/ ? '\s|$' :
+                                  '.|$' );
                     $self->_write_line_GenBank_regex
                         ( " " x 21, " " x 21,
                           "/$tag=\"$value\"", $pat, 80 );
                 }
                 else {
+                    my ($pat) = ( $value =~ /[,]/ ? '[,]|$' :
+                                  '.|$' );
                     $self->_write_line_GenBank_regex
                         ( " " x 21, " " x 21,
-                          "/$tag=$value", "\.\|\$", 80 );
+                          "/$tag=$value", $pat, 80 );
                 }
             }
         }
@@ -1317,7 +1339,7 @@ sub _read_GenBank_References {
     my (@refs);
     my $ref;
 
-    # assumme things are starting with RN
+    # assume things are starting with RN
     if ( $$buffer !~ /^REFERENCE/ ) {
         warn("Not parsing line '$$buffer' which maybe important");
     }
@@ -1551,8 +1573,9 @@ sub _read_GenBank_Species {
             chomp $data;
             $tag = 'CLASSIFICATION' if (    $tag ne 'CLASSIFICATION'
                                         and $tag eq 'ORGANISM'
-                                        # Don't match "str." or "var." (NC_021815)
-                                        and  $line =~ m{(?<!\bstr|\bvar)[;\.]+});
+                                        # Don't match "str." or "var." (fix NC_021815),
+                                        # and don't match ".1" (fix NC_021902)
+                                        and $line =~ m{(?<!\bstr|\bvar)[;\.]+(?!\d)});
         }
         (exists $ann->{$tag}) ? ($ann->{$tag} .= ' '.$data) : ($ann->{$tag} .= $data);
         $line = undef;
@@ -1702,10 +1725,10 @@ sub _read_FTHelper_GenBank {
   QUAL:
     for (my $i = 0; $i < @qual; $i++) {
         my $data = $qual[$i];
-        my ( $qualifier, $value ) = ($data =~ m{^/([^=]+)(?:=(.+))?})
+        my ( $qualifier, $value ) = ($data =~ m{^/([^=]+)(?:=\s*(.+))?})
             or $self->warn(  "cannot see new qualifier in feature $key: "
-                           . $qual[$i]);
-        $qualifier = '' unless( defined $qualifier );
+                           . $data);
+        $qualifier = '' if not defined $qualifier;
 
         if (defined $value) {
             # Do we have a quoted value?
@@ -1821,14 +1844,14 @@ sub _write_line_GenBank {
 sub _write_line_GenBank_regex {
     my ($self, $pre1, $pre2, $line, $regex, $length) = @_;
 
-    #print STDOUT "Going to print with $line!\n";
+    # print STDOUT "Going to print with $line!\n";
 
     $length or $self->throw("Miscalled write_line_GenBank without length. Programming error!");
 
     my $subl  = $length - (length $pre1) - 2;
     my @lines = ();
 
-  CHUNK:
+    CHUNK:
     while ($line) {
         foreach my $pat ($regex, '[,;\.\/-]\s|'.$regex, '[,;\.\/-]|'.$regex) {
             if ($line =~ m/^(.{0,$subl})($pat)(.*)/ ) {
