@@ -1,6 +1,6 @@
 # BioPerl module for Bio::SeqIO::tinyseq
 #
-# Please direct questions and support issues to <bioperl-l@bioperl.org> 
+# Please direct questions and support issues to <bioperl-l@bioperl.org>
 #
 # Cared for by Donald Jackson, donald.jackson@bms.com
 #
@@ -30,7 +30,7 @@ This object reads and writes Bio::Seq objects to and from TinySeq XML
 format.  A TinySeq is a lightweight XML file of sequence information,
 analgous to FASTA format.
 
-See L<http://www.ncbi.nlm.nih.gov/dtd/NCBI_TSeq.mod.dtd> for the DTD.
+See L<https://www.ncbi.nlm.nih.gov/dtd/NCBI_TSeq.mod.dtd> for the DTD.
 
 =head1 FEEDBACK
 
@@ -43,15 +43,15 @@ the Bioperl mailing list.  Your participation is much appreciated.
   bioperl-l@bioperl.org                  - General discussion
   http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
 
-=head2 Support 
+=head2 Support
 
 Please direct usage questions or support issues to the mailing list:
 
 I<bioperl-l@bioperl.org>
 
-rather than to the module maintainer directly. Many experienced and 
-reponsive experts will be able look at the problem and quickly 
-address it. Please include a thorough description of the problem 
+rather than to the module maintainer directly. Many experienced and
+reponsive experts will be able look at the problem and quickly
+address it. Please include a thorough description of the problem
 with code and data examples if at all possible.
 
 =head2 Reporting Bugs
@@ -60,7 +60,7 @@ Report bugs to the Bioperl bug tracking system to help us keep track
 of the bugs and their resolution. Bug reports can be submitted via
 the web:
 
-  http://bugzilla.bioperl.org
+  https://github.com/bioperl/bioperl-live/issues
 
 =head1 SEE ALSO
 
@@ -82,7 +82,7 @@ Internal methods are usually preceded with a _
 =cut
 
 package Bio::SeqIO::tinyseq;
-
+$Bio::SeqIO::tinyseq::VERSION = '1.7.8';
 use strict;
 use Bio::Seq::SeqFastaSpeedFactory;
 use Bio::Species;
@@ -98,7 +98,7 @@ sub _initialize {
     $self->SUPER::_initialize(@args);
 
     unless (defined $self->sequence_factory) {
-	$self->sequence_factory(Bio::Seq::SeqFastaSpeedFactory->new());
+        $self->sequence_factory(Bio::Seq::SeqFastaSpeedFactory->new);
     }
 
     $self->{'_species_objects'} = {};
@@ -107,11 +107,11 @@ sub _initialize {
 
 =head2 next_seq
 
-  Title		: next_seq
-  Usage		: $seq = $stream->next_seq()
-  Function	: returns the next sequence in the stream
-  Returns	: Bio::Seq object
-  Args		: NONE
+  Title   : next_seq
+  Usage   : $seq = $stream->next_seq()
+  Function: returns the next sequence in the stream
+  Returns : Bio::Seq object
+  Args    : NONE
 
 =cut
 
@@ -125,11 +125,11 @@ sub next_seq {
 
 =head2 write_seq
 
-  Title		: write_seq
-  Usage		: $seq = $stream->write_seq(@sequence_objects); undef $stream
-  Function	: outputs one or more sequence objects as TinySeq XML
-  Returns	: 1 on success
-  Args		: one or more sequence objects as TinySeq XML
+  Title   : write_seq
+  Usage   : $seq = $stream->write_seq(@sequence_objects); undef $stream
+  Function: outputs one or more sequence objects as TinySeq XML
+  Returns : 1 on success
+  Args    : one or more sequence objects as TinySeq XML
 
 Because the TSeq dtd includes closing tags after all sets are written,
 the output will not be complete until the program terminates or the
@@ -142,37 +142,38 @@ sub write_seq {
     my ($self, @seqobjs) = @_;
 
     $self->throw('write_seq must be called with at least one  Bio::SeqI or Bio::PrimarySeqI compliant object')
-	unless (@seqobjs and ( $seqobjs[0]->isa('Bio::SeqI') || $seqobjs[0]->isa('Bio::PrimarySeqI')));
+        unless (@seqobjs and ( $seqobjs[0]->isa('Bio::SeqI') || $seqobjs[0]->isa('Bio::PrimarySeqI')));
 
     my $writer = $self->_get_writer;
 
     foreach my $seqobj (@seqobjs) {
-	my ($id_element, $id_value) = $self->_get_idstring($seqobj);
- 	$writer->startTag('TSeq');
-	$writer->emptyTag('TSeq_seqtype', value => $self->_convert_seqtype($seqobj));
-	$writer->dataElement('TSeq_gi', $seqobj->primary_id || '');
-	$writer->dataElement($id_element, $id_value);
-	#$writer->dataElement('TSeq_orgname', $seqobj->taxid) if ($seqobj->can('taxid'); # just a placeholder
-	$writer->dataElement('TSeq_defline', $seqobj->desc);
-	$writer->dataElement('TSeq_length', $seqobj->length);
-	$writer->dataElement('TSeq_sequence', $seqobj->seq);
+        my ($id_element, $id_value) = $self->_get_idstring($seqobj);
+        $writer->startTag('TSeq');
+        $writer->emptyTag('TSeq_seqtype', value => $self->_convert_seqtype($seqobj));
 
-	if ($seqobj->can('species') && $seqobj->species) {
-	    $self->_write_species($writer, $seqobj->species);
-	}
+        $writer->dataElement('TSeq_gi',       $seqobj->primary_id || '');
+        $writer->dataElement($id_element,     $id_value);
+        #$writer->dataElement('TSeq_orgname',  $seqobj->taxid) if ($seqobj->can('taxid')); # just a placeholder
+        $writer->dataElement('TSeq_defline',  $seqobj->desc);
+        $writer->dataElement('TSeq_length',   $seqobj->length);
+        $writer->dataElement('TSeq_sequence', $seqobj->seq);
 
-	$writer->endTag('TSeq');
+        if ($seqobj->can('species') && $seqobj->species) {
+            $self->_write_species($writer, $seqobj->species);
+        }
+
+        $writer->endTag('TSeq');
     }
     1;
 }
 
 =head2 _get_seqs
 
-  Title		: _get_seqs
-  Usage		: Internal function - use next_seq() instead
-  Function	: parses the XML and creates Bio::Seq objects
-  Returns	: 1 on success
-  Args		: NONE
+  Title   : _get_seqs
+  Usage   : Internal function - use next_seq() instead
+  Function: parses the XML and creates Bio::Seq objects
+  Returns : 1 on success
+  Args    : NONE
 
 Currently stores all sequence objects into memory.  I will work on do
 more of a stream-based approach
@@ -181,44 +182,41 @@ more of a stream-based approach
 
 sub _get_seqs {
     my ($self) = @_;
-
     my $fh = $self->_fh;
 
     my $handler = Bio::SeqIO::tinyseq::tinyseqHandler->new();
-    my $parser = XML::Parser::PerlSAX->new( Handler => $handler );
-
+    my $parser  = XML::Parser::PerlSAX->new( Handler => $handler );
     my @seqatts = $parser->parse( Source => { ByteStream => $fh });
-
     my $factory = $self->sequence_factory;
 
     $self->{_seqlist} ||= [];
     foreach my $seqatt(@seqatts) {
-	foreach my $subatt(@$seqatt) { # why are there two hashes?
-	    my $seqobj = $factory->create(%$subatt);
-	    $self->_assign_identifier($seqobj, $subatt);
+        foreach my $subatt(@$seqatt) { # why are there two hashes?
+            my $seqobj = $factory->create(%$subatt);
+            $self->_assign_identifier($seqobj, $subatt);
 
-	    if ($seqobj->can('species')) {
-# 		my $class = [reverse(split(/ /, $subatt->{'-organism'}))];
-# 		my $species = Bio::Species->new( -classification	=> $class,
-# 						 -ncbi_taxid		=> $subatt->{'-taxid'} );
-		my $species = $self->_get_species($subatt->{'-organism'}, $subatt->{'-taxid'});
-		$seqobj->species($species) if ($species);
-	    }
+            if ($seqobj->can('species')) {
+#               my $class = [reverse(split(/ /, $subatt->{'-organism'}))];
+#               my $species = Bio::Species->new( -classification => $class,
+#                                                -ncbi_taxid     => $subatt->{'-taxid'} );
+                my $species = $self->_get_species($subatt->{'-organism'}, $subatt->{'-taxid'});
+                $seqobj->species($species) if ($species);
+            }
 
-	    push(@{$self->{_seqlist}}, $seqobj);
-	}
+            push(@{$self->{_seqlist}}, $seqobj);
+        }
     }
     $self->{_parsed} = 1;
 }
 
 =head2 _get_species
 
-  Title		: _get_species
-  Usage		: Internal function
-  Function	: gets a Bio::Species object from cache or creates as needed
-  Returns	: a Bio::Species object on success, undef on failure
-  Args		: a classification string (eg 'Homo sapiens') and
-                  a NCBI taxon id (optional)
+  Title   : _get_species
+  Usage   : Internal function
+  Function: gets a Bio::Species object from cache or creates as needed
+  Returns : a Bio::Species object on success, undef on failure
+  Args    : a classification string (eg 'Homo sapiens') and
+            a NCBI taxon id (optional)
 
 Objects are cached for parsing multiple sequence files.
 
@@ -228,19 +226,19 @@ sub _get_species {
      my ($self, $orgname, $taxid) = @_;
 
      unless ($self->{'_species_objects'}->{$orgname}) {
-	 my $species = $self->_create_species($orgname, $taxid);
-	 $self->{'_species_objects'}->{$orgname} = $species;
+         my $species = $self->_create_species($orgname, $taxid);
+         $self->{'_species_objects'}->{$orgname} = $species;
      }
      return $self->{'_species_objects'}->{$orgname};
 }
 
 =head2 _create_species
 
-  Title		: _create_species
-  Usage		: Internal function
-  Function	: creates a Bio::Species object
-  Returns	: a Bio::Species object on success, undef on failure
-  Args		: a classification string (eg 'Homo sapiens') and
+  Title   : _create_species
+  Usage   : Internal function
+  Function: creates a Bio::Species object
+  Returns : a Bio::Species object on success, undef on failure
+  Args    : a classification string (eg 'Homo sapiens') and
                   a NCBI taxon id (optional)
 
 =cut
@@ -254,7 +252,7 @@ sub _create_species {
     $params{'-ncbi_taxid'} = $taxid if ($taxid);
 
     my $species = Bio::Species->new(%params)
-	or return;
+        or return;
 
     return $species;
 }
@@ -262,11 +260,11 @@ sub _create_species {
 
 =head2 _assign_identifier
 
-  Title		: _assign_identifier
-  Usage		: Internal function
-  Function	: looks for sequence accession
-  Returns	: 1 on success
-  Args		: NONE
+  Title   : _assign_identifier
+  Usage   : Internal function
+  Function: looks for sequence accession
+  Returns : 1 on success
+  Args    : NONE
 
 NCBI puts refseq accessions in TSeq_sid, others in TSeq_accver.
 
@@ -277,35 +275,34 @@ sub _assign_identifier {
     my ($accession, $version);
 
    if ($atts->{'-accver'}) {
-	($accession, $version) = split(/\./, $atts->{'-accver'});;
+        ($accession, $version) = split(/\./, $atts->{'-accver'});;
     }
     elsif ($atts->{'-sid'}) {
-	my $sidstring =$atts->{'-sid'};
-	$sidstring =~ s/^.+?\|//;
-	$sidstring =~ s/\|[^\|]*//;
-	($accession, $version) = split(/\./, $sidstring);;
+        my $sidstring =$atts->{'-sid'};
+        $sidstring =~ s/^.+?\|//;
+        $sidstring =~ s/\|[^\|]*//;
+        ($accession, $version) = split(/\./, $sidstring);;
     }
     else {
-	$self->throw('NO accession information found for this sequence');
+        $self->throw('NO accession information found for this sequence');
     }
     $seqobj->accession_number($accession) if ($seqobj->can('accession_number'));
     $seqobj->version($version) if ($seqobj->can('version'));
-
 }
 
 =head2 _convert_seqtype
 
-  Title		: _convert_seqtype
-  Usage		: Internal function
-  Function	: maps Bio::Seq::alphabet() values [dna/rna/protein] onto
-                  TSeq_seqtype values [protein/nucleotide]
+  Title   : _convert_seqtype
+  Usage   : Internal function
+  Function: maps Bio::Seq::alphabet() values [dna/rna/protein] onto
+            TSeq_seqtype values [protein/nucleotide]
 
 =cut
 
 sub _convert_seqtype {
     my ($self, $seqobj) = @_;
 
-    return 'protein' 	if ($seqobj->alphabet eq 'protein');
+    return 'protein'    if ($seqobj->alphabet eq 'protein');
     return 'nucleotide' if ($seqobj->alphabet eq 'dna');
     return 'nucleotide' if ($seqobj->alphabet eq 'rna');
 
@@ -315,10 +312,10 @@ sub _convert_seqtype {
 
 =head2 _get_idstring
 
-  Title		: _get_idstring
-  Usage		: Internal function
-  Function	: parse accession and version info from TSeq_accver
-                  or TSeq_sid
+  Title   : _get_idstring
+  Usage   : Internal function
+  Function: parse accession and version info from TSeq_accver
+            or TSeq_sid
 
 =cut
 
@@ -328,18 +325,18 @@ sub _get_idstring {
     my $accver = $seqobj->accession_number;
     $accver .= '.' . $seqobj->version if ($seqobj->can('version') and $seqobj->version);
     if ($accver =~ /^(NM_|NP_|XM_|XP_|NT_|NC_|NG_)/) {
-	return ('TSeq_sid', join('|', 'ref', $accver, ''));
+        return ('TSeq_sid', join('|', 'ref', $accver, ''));
     }
     else {
-	return ('TSeq_accver', $accver);
+        return ('TSeq_accver', $accver);
     }
 }
 
 =head2 _get_writer
 
-  Title		: _get_writer
-  Usage		: Internal function
-  Function	: instantiate XML::Writer object if needed,
+  Title   : _get_writer
+  Usage   : Internal function
+  Function: instantiate XML::Writer object if needed,
                   output initial XML
 
 =cut
@@ -349,30 +346,28 @@ sub _get_writer {
     my ($self) = @_;
 
     unless ($self->{_writer}) {
-	my $fh = $self->_fh;
-	my $writer = XML::Writer->new(OUTPUT 		=> $fh,
-				      DATA_MODE		=> 1,
-				      DATA_INDENT	=> 2,
-				      NEWLINE		=> 1,
-				      );
-	$writer->doctype('TSeqSet', '-//NCBI//NCBI TSeq/EN', 'http://www.ncbi.nlm.nih.gov/dtd/NCBI_TSeq.dtd');
+        my $fh = $self->_fh;
+        my $writer = XML::Writer->new(OUTPUT      => $fh,
+                                      DATA_MODE   => 1,
+                                      DATA_INDENT => 2,
+                                      NEWLINE     => 1,
+                                      );
+        $writer->doctype('TSeqSet', '-//NCBI//NCBI TSeq/EN', 'https://www.ncbi.nlm.nih.gov/dtd/NCBI_TSeq.dtd');
+        $writer->comment("Generated by Bio::SeqIO::tinyseq VERSION " . $Bio::SeqIO::tinyseq::VERSION);
+        $writer->startTag('TSeqSet');
 
-	$writer->comment("Generated by Bio::SeqIO::tinyseq VERSION ".$Bio::SeqIO::tinyseq::VERSION);
-
-	$writer->startTag('TSeqSet');
-
-	$self->{_writer} = $writer;
+        $self->{_writer} = $writer;
     }
     return $self->{_writer};
 }
 
 =head2 close_writer
 
-  Title		: close_writer
-  Usage		: $self->close_writer()
-  Function	: terminate XML output
-  Args		: NONE
-  Returns	: 1 on success
+  Title   : close_writer
+  Usage   : $self->close_writer()
+  Function: terminate XML output
+  Args    : NONE
+  Returns : 1 on success
 
 Called automatically by DESTROY when object goes out of scope
 
@@ -382,10 +377,10 @@ sub close_writer {
     # close out any dangling writer
     my ($self) = @_;
     if ($self->{_writer}) {
-	my $writer = $self->{_writer};
-	$writer->endTag('TSeqSet');
-	$writer->end;
-	undef $writer;
+        my $writer = $self->{_writer};
+        $writer->endTag('TSeqSet');
+        $writer->end;
+        undef $writer;
     }
     close($self->_fh) if ($self->_fh);
     1;
@@ -394,8 +389,8 @@ sub close_writer {
 sub _write_species {
     my ($self, $writer, $species) = @_;
     $writer->dataElement('TSeq_orgname', $species->binomial);
-    $writer->dataElement('TSeq_taxid', $species->ncbi_taxid)
-	if($species->ncbi_taxid);
+    $writer->dataElement('TSeq_taxid',   $species->ncbi_taxid)
+        if($species->ncbi_taxid);
 }
 
 sub DESTROY {
