@@ -31,7 +31,7 @@ in the NCBI TinySeq XML format.  A TinySeq is a lightweight XML file
 of sequence information on one or more sequences, analgous to FASTA
 format.
 
-See L<http://www.ncbi.nlm.nih.gov/dtd/NCBI_TSeq.mod.dtd> for the DTD.
+See L<https://www.ncbi.nlm.nih.gov/dtd/NCBI_TSeq.mod.dtd> for the DTD.
 
 =head1 FEEDBACK
 
@@ -61,7 +61,7 @@ Report bugs to the Bioperl bug tracking system to help us keep track
 of the bugs and their resolution. Bug reports can be submitted via
 the web:
 
-  http://bugzilla.open-bio.org/
+  https://github.com/bioperl/bioperl-live/issues
 
 =head1 SEE ALSO
 
@@ -79,7 +79,7 @@ Internal methods are usually preceded with a _
 =cut
 
 package Bio::SeqIO::tinyseq::tinyseqHandler;
-
+$Bio::SeqIO::tinyseq::tinyseqHandler::VERSION = '1.7.8';
 use strict;
 use warnings;
 
@@ -120,13 +120,13 @@ sub new {
 }
 
 #######################################
-# Event hadling methods for PerlSax   #
+# Event handling methods for PerlSax  #
 #######################################
 
 sub doctype_decl {
     my ($self, $doctype) = @_;
     # make sure we have a tinyseq
-    unless ($doctype->{'SystemId'} eq 'http://www.ncbi.nlm.nih.gov/dtd/NCBI_TSeq.dtd') {
+    unless ($doctype->{'SystemId'} eq 'https://www.ncbi.nlm.nih.gov/dtd/NCBI_TSeq.dtd') {
 	$self->throw("This document doesn't use the NCBI TinySeq dtd; it's a ", $doctype->{'SystemId'} );
     }
 
