@@ -1,4 +1,3 @@
-# $Id: Species.pm 16123 2009-09-17 12:57:27Z cjfields $
 #
 # BioPerl module for Bio::Species
 #
@@ -6,6 +5,7 @@
 #
 # Cared for by James Gilbert <jgrg@sanger.ac.uk>
 # Reimplemented by Sendu Bala <bix@sendu.me.uk>
+# Re-reimplemented by Chris Fields <cjfields - at - bioperl dot org>
 #
 # You may distribute this module under the same terms as perl itself
 
@@ -13,7 +13,7 @@
 
 =head1 NAME
 
-Bio::Species - Generic species object
+Bio::Species - Generic species object.  
 
 =head1 SYNOPSIS
 
@@ -38,16 +38,16 @@ Bio::Species - Generic species object
 
 =head1 DESCRIPTION
 
-Provides a very simple object for storing phylogenetic
-information.  The classification is stored in an array,
-which is a list of nodes in a phylogenetic tree.  Access to
-getting and setting species and genus is provided, but not
-to any of the other node types (eg: "phylum", "class",
-"order", "family").  There's plenty of scope for making the
-model more sophisticated, if this is ever needed.
+B<NOTE: This class is planned for deprecation in favor of the simpler Bio::Taxon.
+Please use that class instead.>
 
-A methods are also provided for storing common
-names, and subspecies.
+Provides a very simple object for storing phylogenetic information. The
+classification is stored in an array, which is a list of nodes in a phylogenetic
+tree. Access to getting and setting species and genus is provided, but not to
+any of the other node types (eg: "phylum", "class", "order", "family"). There's
+plenty of scope for making the model more sophisticated, if this is ever needed.
+
+A methods are also provided for storing common names, and subspecies.
 
 =head1 FEEDBACK
 
@@ -77,7 +77,7 @@ Report bugs to the Bioperl bug tracking system to help us keep track
 of the bugs and their resolution. Bug reports can be submitted via the
 web:
 
-  http://bugzilla.open-bio.org/
+  https://github.com/bioperl/bioperl-live/issues
 
 =head1 AUTHOR
 
@@ -86,6 +86,7 @@ James Gilbert email B<jgrg@sanger.ac.uk>
 =head1 CONTRIBUTORS
 
 Sendu Bala, bix@sendu.me.uk
+Chris Fields, cjfields at bioperl dot org
 
 =head1 APPENDIX
 
@@ -97,12 +98,14 @@ methods. Internal methods are usually preceded with a _
 #' Let the code begin...
 
 package Bio::Species;
+$Bio::Species::VERSION = '1.7.8';
 use strict;
+use warnings;
 
 use Bio::DB::Taxonomy;
 use Bio::Tree::Tree;
-use Scalar::Util qw(weaken isweak);
-use base qw(Bio::Taxon);
+use Bio::Taxon;
+use base qw(Bio::Root::Root Bio::Tree::NodeI);
 
 =head2 new
 
@@ -120,22 +123,28 @@ sub new {
     
     my $self = $class->SUPER::new(@args);
     
+    # Bio::Species is now just a proxy object that just observes the NodeI
+    # interface methods but delegates them to the proper classes (Bio::Taxon and
+    # Bio::Tree::Tree). This will be surplanted by the much simpler
+    # Bio::Taxon/Bio::DB::Taxonomy modules in the future.
+    
+    # Using a proxy allows proper GC w/o using weaken().  This just wraps the
+    # older instances, which have no reciprocal refs (thus no circular refs).
+    # This can then run proper cleanup
+    
+    $self->taxon(Bio::Taxon->new(@args));
+    
     my ($org, $sp, $var, $classification) =
         $self->_rearrange([qw(ORGANELLE
-					       SUB_SPECIES
-					       VARIANT
-					       CLASSIFICATION)], @args);
+                            SUB_SPECIES
+                            VARIANT
+                            CLASSIFICATION)], @args);
     
     if (defined $classification && ref($classification) eq "ARRAY" && @{$classification}) {
         $self->classification(@$classification);
     }
     else {
-        # store a tree on ourselves so we can use Tree methods
-        $self->{tree} = Bio::Tree::Tree->new();
-        
-        # some things want to freeze/thaw Bio::Species objects, but
-        # _root_cleanup_methods contains a CODE ref, delete it.
-        # delete $self->{tree}->{_root_cleanup_methods};
+        $self->tree(Bio::Tree::Tree->new());
     }
     
     defined $org && $self->organelle($org);
@@ -168,21 +177,26 @@ sub new {
 sub classification {
     my ($self, @vals) = @_;
 
+    my $taxon = $self->taxon;
+
     if (@vals) {
         if (ref($vals[0]) eq 'ARRAY') {
             @vals = @{$vals[0]};
         }
         
+        $vals[1] ||= '';
         # make sure the lineage contains us as first or second element
         # (lineage may have subspecies, species, genus ...)
-        my $name = $self->node_name;
+        my $name = $taxon->node_name;
         my ($genus, $species) = (quotemeta($vals[1]), quotemeta($vals[0]));
-        if ($name && ($name !~ m{$species}i && $name !~ m{$genus}i) && $name !~ m{$vals[1] $vals[0]}i) {
-            if ($name =~ /^$vals[1] $vals[0]\s*(.+)/) {
+        if ($name && 
+           ($name !~ m{$species}i && $name !~ m{$genus}i) && 
+            $name !~ m{$genus $species}i) {
+            if ($name =~ /^$genus $species\s*(.+)/) {
                 # just assume the problem is someone tried to make a Bio::Species starting at subspecies
                 #*** no idea if this is appropriate! just a possible fix related to bug 2092
                 $self->sub_species($1);
-                $name = $self->node_name("$vals[1] $vals[0]");
+                $name = $taxon->node_name("$vals[1] $vals[0]");
             }
             else {
                 $self->warn("The supplied lineage does not start near '$name' (I was supplied '".join(" | ", @vals)."')");
@@ -191,31 +205,24 @@ sub classification {
         
         # create a lineage for ourselves
         my $db = Bio::DB::Taxonomy->new(-source => 'list', -names => [reverse @vals]);
-        unless ($self->scientific_name) {
+        unless ($taxon->scientific_name) {
             # assume we're supposed to be the leaf of the supplied lineage
-            $self->scientific_name($vals[0]);
+            $self->taxon->scientific_name($vals[0]);
         }
-        unless ($self->rank) {
+        unless ($taxon->rank) {
             # and that we are rank species
-            $self->rank('species');
+            $taxon->rank('species');
         }
         
-        $self->db_handle($db);
-
-        $self->{tree} = Bio::Tree::Tree->new(-node => $self);
-        # some things want to freeze/thaw Bio::Species objects, but tree's
-        # _root_cleanup_methods contains a CODE ref, delete it.
-        #*** even if we don't delete the cleanup methods, we still get memory
-        #    leak-like symtoms, and the actual cleanup causes a mass of
-        #    warnings... needs investigation!
-        delete $self->{tree}->{_root_cleanup_methods};
+        $taxon->db_handle($db);
+        
+        $self->tree(Bio::Tree::Tree->new(-node => $taxon));
     }
     
     @vals = ();
-    foreach my $node ($self->{tree}->get_lineage_nodes($self), $self) {
+    foreach my $node ($self->tree->get_lineage_nodes($taxon), $taxon) {
         unshift(@vals, $node->scientific_name || next);
     }
-    weaken($self->{tree}->{'_rootnode'}) unless isweak($self->{tree}->{'_rootnode'});
     return @vals;
 }
 
@@ -256,10 +263,12 @@ sub classification {
  Title   : species
  Usage   : $self->species( $species );
            $species = $self->species();
- Function: Get or set the scientific species name.
- Example : $self->species('Homo sapiens');
- Returns : Scientific species name as string
- Args    : Scientific species name as string
+ Function: Get or set the species name.
+           Note that this is  NOT genus and species
+           -- use $self->binomial() for that.
+ Example : $self->species('sapiens');
+ Returns : species name as string (NOT genus and species)
+ Args    : species name as string (NOT genus and species)
 
 =cut
 
@@ -269,15 +278,15 @@ sub species {
 	if ($species) {
 		$self->{_species} = $species;
 	}
-	
+
 	unless (defined $self->{_species}) {
 		# work it out from our nodes
-		my $species_taxon = $self->{tree}->find_node(-rank => 'species');
+		my $species_taxon = $self->tree->find_node(-rank => 'species');
 		unless ($species_taxon) {
 			# just assume we are rank species
-			$species_taxon = $self;
+			$species_taxon = $self->taxon;
 		}
-		
+
 		$species = $species_taxon->scientific_name;
         
 		#
@@ -285,19 +294,17 @@ sub species {
 		# (more or less copy/pasted from old Bio::SeqIO::genbank, hence comments
 		#  referring to 'ORGANISM' etc.)
 		#
-		
-		my $root = $self->{tree}->get_root_node;
+
+		my $root = $self->tree->get_root_node;
 		unless ($root) {
-            $self->{tree} = Bio::Tree::Tree->new(-node => $species_taxon);
-            delete $self->{tree}->{_root_cleanup_methods};
-            $root = $self->{tree}->get_root_node;
-            weaken($self->{tree}->{'_rootnode'}) unless isweak($self->{tree}->{'_rootnode'});
+            $self->tree(Bio::Tree::Tree->new(-node => $species_taxon));
+            $root = $self->tree->get_root_node;
         }
         
 		my @spflds = split(' ', $species);
 		if (@spflds > 1 && $root->node_name ne 'Viruses') {
 			$species = undef;
-			
+
 			# does the next term start with uppercase?
 			# yes: valid genus; no then unconventional
 			# e.g. leaf litter basidiomycete sp. Collb2-39
@@ -322,7 +329,7 @@ sub species {
 			else {
 				$species = 'sp.';
 			}
-			
+
 			# does ORGANISM start with any words which make its genus undefined?
 			# these are in @unkn_genus	
 			# this in case species starts with uppercase so isn't caught above. 
@@ -348,11 +355,11 @@ sub species {
 				# $sub_species='thummi'
 				$sub_species = $2;
 			}
-			
+
 			$self->genus($genus) if $genus;
 			$self->sub_species($sub_species) if $sub_species;
 		}
-		
+
 		$self->{_species} = $species;
     }
 	return $self->{_species};
@@ -372,22 +379,22 @@ sub species {
 
 sub genus {
     my ($self, $genus) = @_;
-    
-	if ($genus) {
+
+    # TODO: instead of caching the raw name, cache the actual node instance.
+    if ($genus) {
         $self->{_genus} = $genus;
     }
-	
-	unless (defined $self->{_genus}) {
-		my $genus_taxon = $self->{tree}->find_node(-rank => 'genus');
-		unless ($genus_taxon) {
-			# just assume our ancestor is rank genus
-			$genus_taxon = $self->ancestor;
-		}
-		
-		$self->{_genus} = $genus_taxon->scientific_name if $genus_taxon;
-	}
-	
-	return $self->{_genus};
+    unless (defined $self->{_genus}) {
+        my $genus_taxon = $self->tree->find_node(-rank => 'genus');
+        unless ($genus_taxon) {
+            # just assume our ancestor is rank genus
+            $genus_taxon = $self->taxon->ancestor;
+        }
+        
+        $self->{_genus} = $genus_taxon->scientific_name if $genus_taxon;
+    }
+    
+    return $self->{_genus};
 }
 
 =head2 sub_species
@@ -403,8 +410,9 @@ sub genus {
 sub sub_species {
     my ($self, $sub) = @_;
     
-    unless (defined $self->{'_sub_species'}) {
-        my $ss_taxon = $self->{tree}->find_node(-rank => 'subspecies');
+    # TODO: instead of caching the raw name, cache the actual node instance.
+    if (!defined $self->{'_sub_species'}) {
+        my $ss_taxon = $self->tree->find_node(-rank => 'subspecies');
         if ($ss_taxon) {
             if ($sub) {
                 $ss_taxon->scientific_name($sub);
@@ -416,10 +424,18 @@ sub sub_species {
                 # value. So we 'cheat' and just store the subspecies name in
                 # our self hash, instead of the tree. Is this a problem for
                 # a Species object? Can't decide --sendu
+                
+                # This can now be changed to deal with this information on the
+                # fly.  For now, the caching remains, but maybe we should just
+                # let these things deal with mutable data as needed? -- cjfields
+                
                 $self->{'_sub_species'} = $sub;
             }
             return $ss_taxon->scientific_name;
         }
+        else {
+            # should we create a node here to be added to the tree?
+        }
     }
     
     # fall back to direct storage on self
@@ -442,14 +458,18 @@ sub sub_species {
 sub variant{
     my ($self, $var) = @_;
     
-    unless (defined $self->{'_variant'}) {
-        my $var_taxon = $self->{tree}->find_node(-rank => 'variant');
+    # TODO: instead of caching the raw name, cache the actual node instance.
+    if (!defined $self->{'_variant'}) {
+        my $var_taxon = $self->tree->find_node(-rank => 'variant');
         if ($var_taxon) {
             if ($var) {
                 $var_taxon->scientific_name($var);
             }
             return $var_taxon->scientific_name;
         }
+        else {
+            # should we create a node here to be added to the tree?
+        }
     }
     
     # fall back to direct storage on self
@@ -466,12 +486,13 @@ sub variant{
            if the first argument is 'FULL' (and the species has a subspecies).
  Args    : Optionally the string 'FULL' to get the full name including
            the subspecies.
+ Note    : This is just munged from the taxon() name
 
 =cut
 
 sub binomial {
     my ($self, $full) = @_;
-    my $rank = $self->rank || 'no rank';
+    my $rank = $self->taxon->rank || 'no rank';
     
     my ($species, $genus) = ($self->species, $self->genus);
     unless (defined $species) {
@@ -500,21 +521,20 @@ sub binomial {
  Usage   : $result = $self->validate_species_name($string);
  Function: Validate the species portion of the binomial
  Args    : string
- Notes   : The string following the "genus name" in the NCBI binomial
-           is so variable that it's not clear that this is a useful
-           function. Consider the binomials 
-           "Simian 11 rotavirus (serotype 3 / strain SA11-Patton)",
-           or "St. Thomas 3 rotavirus", straight from GenBank.
-           This is particularly problematic in microbes and viruses.
-           As such, this isn't actually used automatically by any Bio::Species
-           method.
+ Notes   : The string following the "genus name" in the NCBI binomial is so
+           variable that it's not clear that this is a useful function. Consider
+           the binomials "Simian 11 rotavirus (serotype 3 / strain
+           SA11-Patton)", or "St. Thomas 3 rotavirus", straight from GenBank.
+           This is particularly problematic in microbes and viruses. As such,
+           this isn't actually used automatically by any Bio::Species method.
+
 =cut
 
 sub validate_species_name {
     my( $self, $string ) = @_;
 
     return 1 if $string eq "sp.";
-	return 1 if $string =~ /strain/;
+    return 1 if $string =~ /strain/;
     return 1 if $string =~ /^[a-z][\w\s-]+$/i;
     $self->throw("Invalid species name '$string'");
 }
@@ -532,6 +552,9 @@ sub validate_name {
  Example : $self->organelle('Chloroplast')
  Returns : The organelle name in a string
  Args    : String, which is the organelle name
+ Note    : TODO: We currently do not know where the organelle definition will
+           eventually go.  This is stored in the source seqfeature, though,
+           so the information isn't lost.
 
 =cut
 
@@ -541,11 +564,96 @@ sub organelle {
     return $self->{'_organelle'};
 }
 
-sub dont_DESTROY {
+=head2 Delegation
+
+The following methods delegate to the internal Bio::Taxon instance. This is
+mainly to allow code continue using older methods, with the mind to migrate to
+using Bio::Taxon and related methods when this class is deprecated.
+
+=cut 
+
+sub node_name {shift->taxon->node_name(@_)}
+sub scientific_name {shift->taxon->node_name(@_)}
+
+sub id {shift->taxon->id(@_)}
+sub object_id {shift->taxon->id(@_)}
+sub ncbi_taxid {shift->taxon->ncbi_taxid(@_)}
+sub rank {shift->taxon->rank(@_)}
+sub division {shift->taxon->division(@_)}
+
+sub common_names {shift->taxon->common_names(@_)}
+sub common_name {shift->taxon->common_names(@_)}
+
+sub genetic_code {shift->taxon->genetic_code(@_)}
+sub mitochondrial_genetic_code {shift->taxon->mitochondrial_genetic_code(@_)}
+
+sub create_date { shift->taxon->create_date(@_)}
+sub pub_date { shift->taxon->pub_date(@_)}
+sub update_date { shift->taxon->update_date(@_)}
+
+sub db_handle { shift->taxon->db_handle(@_)}
+
+sub parent_id { shift->taxon->parent_id(@_)}
+sub parent_taxon_id { shift->taxon->parent_id(@_)}
+
+sub version { shift->taxon->version(@_)}
+sub authority { shift->taxon->authority(@_)}
+sub namespace { shift->taxon->namespace(@_)}
+
+sub ancestor { shift->taxon->ancestor(@_)}
+sub get_Parent_Node { shift->taxon->get_Parent_Node(@_)}
+sub each_Descendent { shift->taxon->each_Descendent(@_)}
+sub get_Children_Nodes { shift->taxon->get_Children_Nodes(@_)}
+sub remove_Descendant { shift->taxon->remove_Descendant(@_)}
+
+sub name { shift->taxon->name(@_)}
+
+=head2 taxon
+
+ Title    : taxon
+ Usage    : $obj->taxon
+ Function : retrieve the internal Bio::Taxon instance
+ Returns  : A Bio::Taxon. If one is not previously set,
+            an instance is created lazily
+ Args     : Bio::Taxon (optional)
+ 
+=cut
+
+sub taxon {
+    my ($self, $taxon) = @_;
+    if (!$self->{taxon} || $taxon) {
+        $taxon ||= Bio::Taxon->new();
+        $self->{taxon} = $taxon;
+    }
+    $self->{taxon};
+}
+
+=head2 tree
+
+ Title    : tree
+ Usage    : $obj->tree
+ Function : Returns a Bio::Tree::Tree object
+ Returns  : A Bio::Tree::Tree. If one is not previously set,
+            an instance is created lazily
+ Args     : Bio::Tree::Tree (optional)
+ 
+=cut
+
+sub tree {
+    my ($self, $tree) = @_;
+    if (!$self->{tree} || $tree) {
+        $tree ||= Bio::Tree::Tree->new();
+        delete $tree->{_root_cleanup_methods};
+        $self->{tree} = $tree;
+    }
+    $self->{tree};
+}
+
+sub DESTROY {
     my $self = shift;
-    $self->{tree}->cleanup_tree if $self->{tree};
+    $self->tree->cleanup_tree;
     delete $self->{tree};
-    $self->node_cleanup;
+    $self->taxon->node_cleanup;
 }
 
 1;
