@@ -1,13 +1,16 @@
-# $Id: GuessSeqFormat.pm,v 1.5 2003/12/16 16:58:51 smckay Exp $
 #------------------------------------------------------------------
 #
 # BioPerl module Bio::Tools::GuessSeqFormat
 #
-# Cared for by Andreas Khri, andreas.kahari@ebi.ac.uk
+# Please direct questions and support issues to <bioperl-l@bioperl.org> 
+#
+# Cared for by Andreas Kähäri, andreas.kahari@ebi.ac.uk
 #
 # You may distribute this module under the same terms as perl itself
 #------------------------------------------------------------------
 
+=encoding utf-8
+
 =head1 NAME
 
 Bio::Tools::GuessSeqFormat - Module for determining the sequence
@@ -17,29 +20,29 @@ filehandle.
 =head1 SYNOPSIS
 
     # To guess the format of a flat file, given a filename:
-    my $guesser = new Bio::Tools::GuessSeqFormat( -file => $filename );
+    my $guesser = Bio::Tools::GuessSeqFormat->new( -file => $filename );
     my $format  = $guesser->guess;
 
     # To guess the format from an already open filehandle:
-    my $guesser = new Bio::Tools::GuessSeqFormat( -fh => $filehandle );
+    my $guesser = Bio::Tools::GuessSeqFormat->new( -fh => $filehandle );
     my $format  = $guesser->guess;
-    # If the filehandle is seekable (STDIN isn't), it will be
-    # returned to its original position.
+    # The filehandle will be returned to its original position. Note that this
+    # filehandle can be STDIN.
 
     # To guess the format of one or several lines of text (with
     # embedded newlines):
-    my $guesser = new Bio::Tools::GuessSeqFormat( -text => $linesoftext );
+    my $guesser = Bio::Tools::GuessSeqFormat->new( -text => $linesoftext );
     my $format = $guesser->guess;
 
     # To create a Bio::Tools::GuessSeqFormat object and set the
     # filename, filehandle, or line to parse afterwards:
-    my $guesser = new Bio::Tools::GuessSeqFormat;
+    my $guesser = Bio::Tools::GuessSeqFormat->new();
     $guesser->file($filename);
     $guesser->fh($filehandle);
     $guesser->text($linesoftext);
 
     # To guess in one go, given e.g. a filename:
-    my $format = new Bio::Tools::GuessSeqFormat( -file => $filename )->guess;
+    my $format = Bio::Tools::GuessSeqFormat->new( -file => $filename )->guess;
 
 =head1 DESCRIPTION
 
@@ -52,9 +55,9 @@ examine the data, line by line, until it finds a line to which
 only one format can be assigned.  If no conclusive guess can be
 made, undef is returned.
 
-If the Bio::Tools::GuessSeqFormat object is given a filehandle
-which is seekable, it will be restored to its original position
-on return from the guess() method.
+If the Bio::Tools::GuessSeqFormat object is given a filehandle,
+e.g. STDIN, it will be restored to its original position on
+return from the guess() method.
 
 =head2 Formats
 
@@ -88,6 +91,10 @@ FastA sequence ("fasta")
 
 =item *
 
+FastQ sequence ("fastq")
+
+=item *
+
 FastXY/FastA alignment ("fastxy")
 
 =item *
@@ -186,6 +193,10 @@ Swissprot ("swiss")
 
 Tab ("tab")
 
+=item *
+
+Variant Call Format ("vcf")
+
 =back
 
 =head1 FEEDBACK
@@ -197,38 +208,47 @@ other Bioperl modules.  Send your comments and suggestions
 preferably to one of the Bioperl mailing lists.  Your
 participation is much appreciated.
 
-   bioperl-l@bioperl.org              - General discussion
-   http://bioperl.org/MailList.shtml  - About the mailing lists
+  bioperl-l@bioperl.org                  - General discussion
+  http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
+
+=head2 Support 
+
+Please direct usage questions or support issues to the mailing list:
+
+I<bioperl-l@bioperl.org>
+
+rather than to the module maintainer directly. Many experienced and 
+reponsive experts will be able look at the problem and quickly 
+address it. Please include a thorough description of the problem 
+with code and data examples if at all possible.
 
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us
 keep track the bugs and their resolution.  Bug reports can be
-submitted via email or the web:
+submitted via the web:
 
-    bioperl-bugs@bio.perl.org
-    http://bugzilla.bioperl.org/
+  https://github.com/bioperl/bioperl-live/issues
 
 =head1 AUTHOR
 
-Andreas Khri, andreas.kahari@ebi.ac.uk
+Andreas KE<228>hE<228>ri, andreas.kahari@ebi.ac.uk
 
 =head1 CONTRIBUTORS
 
-Heikki Lehvslaiho, heikki@ebi.ac.uk
+Heikki LehvE<228>slaiho, heikki-at-bioperl-dot-org
+Mark A. Jensen, maj-at-fortinbras-dot-us
 
 =cut
 
 
 package Bio::Tools::GuessSeqFormat;
-
+$Bio::Tools::GuessSeqFormat::VERSION = '1.7.8';
 use strict;
 use warnings;
 
-use Bio::Root::Root;
 
-use vars qw(@ISA);
-@ISA = qw(Bio::Root::Root);
+use base qw(Bio::Root::Root);
 
 =head1 METHODS
 
@@ -241,12 +261,12 @@ underscore are considered to be internal.
 =head2 new
 
  Title      : new
- Usage      : $guesser = new Bio::Tools::GuessSeqFormat( ... );
+ Usage      : $guesser = Bio::Tools::GuessSeqFormat->new( ... );
  Function   : Creates a new object.
  Example    : See SYNOPSIS.
  Returns    : A new object.
  Arguments  : -file The filename of the file whose format is to
-                    be guessed, or
+                    be guessed, e.g. STDIN, or
               -fh   An already opened filehandle from which a text
                     stream may be read, or
               -text A scalar containing one or several lines of
@@ -386,20 +406,21 @@ sub text
               format can not be found, undef is returned.
  Arguments  : None.
 
-    If the object is associated with a filehandle and if that
-    filehandle is searchable, the position of the filehandle
-    will be returned to its original position before the method
-    returns.
+    If the object is associated with a filehandle, the position
+    of the filehandle will be returned to its original position
+    before the method returns.
 
 =cut
 
 our %formats = (
     ace         => { test => \&_possibly_ace        },
     blast       => { test => \&_possibly_blast      },
+    bowtie      => { test => \&_possibly_bowtie     },
     clustalw    => { test => \&_possibly_clustalw   },
     codata      => { test => \&_possibly_codata     },
     embl        => { test => \&_possibly_embl       },
     fasta       => { test => \&_possibly_fasta      },
+    fastq       => { test => \&_possibly_fastq      },
     fastxy      => { test => \&_possibly_fastxy     },
     game        => { test => \&_possibly_game       },
     gcg         => { test => \&_possibly_gcg        },
@@ -414,76 +435,75 @@ our %formats = (
     mase        => { test => \&_possibly_mase       },
     mega        => { test => \&_possibly_mega       },
     msf         => { test => \&_possibly_msf        },
-    phrap       => { test => \&_possibly_phrap      },
-    pir         => { test => \&_possibly_pir        },
     pfam        => { test => \&_possibly_pfam       },
+    phrap       => { test => \&_possibly_phrap      },
     phylip      => { test => \&_possibly_phylip     },
+    pir         => { test => \&_possibly_pir        },
     prodom      => { test => \&_possibly_prodom     },
     raw         => { test => \&_possibly_raw        },
     rsf         => { test => \&_possibly_rsf        },
     selex       => { test => \&_possibly_selex      },
     stockholm   => { test => \&_possibly_stockholm  },
     swiss       => { test => \&_possibly_swiss      },
-    tab         => { test => \&_possibly_tab        }
+    tab         => { test => \&_possibly_tab        },
+    vcf         => { test => \&_possibly_vcf        },
 );
 
 sub guess
 {
     my $self = shift;
 
-    foreach my $fmt_key (keys %formats) {
+    while (my ($fmt_key) = each (%formats)) {
         $formats{$fmt_key}{fmt_string} = $fmt_key;
     }
 
     my $fh;
     my $start_pos;
-    my @lines;
     if (defined $self->{-text}) {
-	# Break the text into separate lines.
-	@lines = split /\n/, $self->{-text};
+        # Break the text into separate lines.
+        my $text = $self->{-text};
+        open $fh, '<', \$text or $self->throw("Could not read from string: $!");
+
     } elsif (defined $self->{-file}) {
         # If given a filename, open the file.
-        open($fh, $self->{-file}) or
-            die "Can not open '$self->{-file}' for reading: $!";
+        my $file = $self->{-file};
+        open $fh, '<', $file or $self->throw("Could not read file '$file': $!");
+
     } elsif (defined $self->{-fh}) {
-        # If given a filehandle, figure out if it's a plain GLOB
-        # or a IO::Handle which is seekable.  In the case of a
-        # GLOB, we'll assume it's seekable.  Get the current
-        # position in the stream.
+        # If given a filehandle, get the current position in the stream.
         $fh = $self->{-fh};
-        if (ref $fh eq 'GLOB') {
-            $start_pos = tell($fh);
-        } elsif (UNIVERSAL::isa($fh, 'IO::Seekable')) {
-            $start_pos = $fh->getpos();
+        if (not seek $fh, 0, 1) { # seek to current position to determine seekability
+            # Work around non-seekable filehandles if IO::Scalar is available
+            # (adapted from http://www.perlmonks.org/?node_id=33587)
+            # IO::Mark may be an option for very large streams?
+            $self->throw("Need IO::Scalar to guess from unseekable filehandles")
+                if not eval { require IO::Scalar };
+            my $data;
+            { local $/; $data = <$fh>; $.-- };  # copy raw data from fh
+            tie *$fh, 'IO::Scalar', my $s;      # replace fh by scalar-tied fh
+            print $fh $data;                    # write raw data to tied fh
+            seek $fh, 0, 0;                     # return to start of tied fh
         }
+        $start_pos = tell $fh;
     }
 
     my $done  = 0;
     my $lineno = 0;
-    my $fmt_string;
+    my $guess;
     while (!$done) {
         my $line;       # The next line of the file.
         my $match = 0;  # Number of possible formats of this line.
 
-	if (defined $self->{-text}) {
-	    last if (scalar @lines == 0);
-	    $line = shift @lines;
-	} else {
-	    last if (!defined($line = <$fh>));
-	}
+        last if (!defined($line = <$fh>));
         next if ($line =~ /^\s*$/); # Skip white and empty lines.
-
-        chomp($line);
+        chomp $line;
         $line =~ s/\r$//;   # Fix for DOS files on Unix.
         ++$lineno;
 
         while (my ($fmt_key, $fmt) = each (%formats)) {
             if ($fmt->{test}($line, $lineno)) {
                 ++$match;
-                $fmt_string = $fmt->{fmt_string};
-                # Debugging:
-                #FIXME#printf STDERR "%s: %s\n", $fmt_string, $line;
-                    #FIXME#if $self->verbose > 0;
+                $guess = $fmt->{fmt_string};
             }
         }
 
@@ -491,17 +511,14 @@ sub guess
         $done = ($match == 1);
     }
 
-    if (defined $self->{-file}) {
-        # Close the file we opened.
-        close($fh);
-    } elsif (ref $fh eq 'GLOB') {
-        # Try seeking to the start position.
-        seek($fh, $start_pos, 0);
-    } elsif (defined $fh && $fh->can('setpos')) {
-        # Seek to the start position.
-        $fh->setpos($start_pos);
+    if (defined $self->{-fh}) {
+        # Go back to original position in filehandle
+        seek $fh, $start_pos, 0 or $self->throw("Could not reset filehandle $fh: $!");
+    } else {
+        # Close the filehandle we opened
+        close $fh;
     }
-    return ($done ? $fmt_string : undef);
+    return ($done ? $guess : undef);
 }
 
 =head1 HELPER SUBROUTINES
@@ -511,13 +528,12 @@ number of the same line, return 1 if the line possibly is from a
 file of the type that they perform a test of.
 
 A zero return value does not mean that the line is not part
-of a certain type of file, just that the test didn't find any
+of a certain type of file, just that the test did not find any
 characteristics of that type of file in the line.
 
 =head2 _possibly_ace
 
-From bioperl test data, and
-from
+From bioperl test data, and from
 "http://www.isrec.isb-sib.ch/DEA/module8/B_Stevenson/Practicals/transcriptome_recon/transcriptome_recon.html".
 
 =cut
@@ -530,7 +546,7 @@ sub _possibly_ace
 
 =head2 _possibly_blast
 
-From various blast results.
+ From various blast results.
 
 =cut
 
@@ -541,6 +557,19 @@ sub _possibly_blast
         $line =~ /^[[:upper:]]*BLAST[[:upper:]]*.*\[.*\]$/);
 }
 
+=head2 _possibly_bowtie
+
+Contributed by kortsch.
+
+=cut
+
+sub _possibly_bowtie
+{
+    my ($line, $lineno) = (shift, shift);
+    return ($line =~ /^[[:graph:]]+\t[-+]\t[[:graph:]]+\t\d+\t([[:alpha:]]+)\t([[:graph:]]+)\t\d+\t[[:graph:]]?/)
+            && length($1)==length($2);
+}
+
 =head2 _possibly_clustalw
 
 From "http://www.ebi.ac.uk/help/formats.html".
@@ -564,7 +593,7 @@ sub _possibly_codata
     my ($line, $lineno) = (shift, shift);
     return (($lineno == 1 && $line =~ /^ENTRY/) ||
             ($lineno == 2 && $line =~ /^SEQUENCE/) ||
-            $line =~ /^(?:ENTRY|SEQUENCE|\/\/\/)/);
+            $line =~ m{^(?:ENTRY|SEQUENCE|///)});
 }
 
 =head2 _possibly_embl
@@ -590,7 +619,20 @@ sub _possibly_fasta
 {
     my ($line, $lineno) = (shift, shift);
     return (($lineno != 1 && $line =~ /^[A-IK-NP-Z]+$/i) ||
-            $line =~ /^>\w/);
+            $line =~ /^>\s*\w/);
+}
+
+=head2 _possibly_fastq
+
+From bioperl test data.
+
+=cut
+
+sub _possibly_fastq
+{
+    my ($line, $lineno) = (shift, shift);
+    return ( ($lineno == 1 && $line =~ /^@/) ||
+             ($lineno == 3 && $line =~ /^\+/) );
 }
 
 =head2 _possibly_fastxy
@@ -621,8 +663,6 @@ sub _possibly_game
 =head2 _possibly_gcg
 
 From bioperl, Bio::SeqIO::gcg.
-Example at
-"http://bioweb.cgb.indiana.edu/seqanal/formats/examples.html#gcg".
 
 =cut
 
@@ -679,7 +719,7 @@ sub _possibly_gde
 
 From "http://www.ebi.ac.uk/help/formats.html".
 Format of [apparantly optional] file header from
-"http://www.umdnj.edu/rcompweb/PA/Notes/GenbankFF.htm".
+"http://www.umdnj.edu/rcompweb/PA/Notes/GenbankFF.htm". (TODO: dead link)
 
 =cut
 
@@ -747,7 +787,7 @@ sub _possibly_nexus
 =head2 _possibly_mase
 
 From bioperl test data.
-More detail from "http://www.umdnj.edu/rcompweb/PA/Notes/GenbankFF.htm".
+More detail from "http://www.umdnj.edu/rcompweb/PA/Notes/GenbankFF.htm" (TODO: dead link)
 
 =cut
 
@@ -775,22 +815,19 @@ sub _possibly_mega
 
 From "http://www.ebi.ac.uk/help/formats.html".
 
-Contradiction at
-"http://bioweb.cgb.indiana.edu/seqanal/formats/examples.html#msf".
-
 =cut
 
 sub _possibly_msf
 {
     my ($line, $lineno) = (shift, shift);
-    return ($line =~ /^\/\// ||
+    return ($line =~ m{^//} ||
             $line =~ /MSF:.*Type:.*Check:|Name:.*Len:/);
 }
 
 =head2 _possibly_phrap
 
-From "http://www.ccgb.umn.edu/biodata/docs/contigimage.html".
-From "http://genetics.gene.cwru.edu/gene508/Lec6.htm".
+From "http://biodata.ccgb.umn.edu/docs/contigimage.html". (TODO: dead link)
+From "http://genetics.gene.cwru.edu/gene508/Lec6.htm".    (TODO: dead link)
 From bioperl test data ("*.ace.1" files).
 
 =cut
@@ -825,7 +862,7 @@ From bioperl test data.
 sub _possibly_pfam
 {
     my ($line, $lineno) = (shift, shift);
-    return ($line =~ /^\w+\/\d+-\d+\s+[A-IK-NP-Z.]+/i);
+    return ($line =~ m{^\w+/\d+-\d+\s+[A-IK-NP-Z.]+}i);
 }
 
 =head2 _possibly_phylip
@@ -840,12 +877,14 @@ sub _possibly_phylip
 {
     my ($line, $lineno) = (shift, shift);
     return (($lineno == 1 && $line =~ /^\s*\d+\s\d+/) ||
-            ($line =~ /^seq\d/));
+            ($lineno == 2 && $line =~ /^\w\s+[A-IK-NP-Z\s]+/) ||
+            ($lineno == 3 && $line =~ /(?:^\w\s+[A-IK-NP-Z\s]+|\s+[A-IK-NP-Z\s]+)/)
+           );
 }
 
 =head2 _possibly_prodom
 
-From "http://prodes.toulouse.inra.fr/prodom/2002.1/documentation/data.php".
+From "http://prodom.prabi.fr/prodom/current/documentation/data.php".
 
 =cut
 
@@ -864,7 +903,7 @@ From "http://www.ebi.ac.uk/help/formats.html".
 sub _possibly_raw
 {
     my ($line, $lineno) = (shift, shift);
-    return ($line =~ /^(?:[sA-IK-NP-Z]+|[sa-ik-np-z]+)$/);
+    return ($line =~ /^[A-Za-z\s]+$/);
 }
 
 =head2 _possibly_rsf
@@ -884,11 +923,9 @@ sub _possibly_rsf
 
 =head2 _possibly_selex
 
-From
-"http://www-ccmr-nmr.bioc.cam.ac.uk/private/arcr1/hmmer-html/node35.html"
-and "http://www.ebc.ee/WWW/hmmer2-html/node27.html".
+From "http://www.ebc.ee/WWW/hmmer2-html/node27.html".
 
-Assuming precense of Selex file header.  Data exported by
+Assuming presence of Selex file header.  Data exported by
 Bioperl on Pfam and Selex formats are identical, but Pfam file
 only holds one alignment.
 
@@ -941,4 +978,22 @@ sub _possibly_tab
     return ($lineno == 1 && $line =~ /^[^\t]+\t[^\t]+/) ;
 }
 
+=head2 _possibly_vcf
+
+From "http://www.1000genomes.org/wiki/analysis/vcf4.0".
+
+Assumptions made about sanity - format and date lines are line 1 and 2
+respectively. This is not specified in the format document.
+
+=cut
+
+sub _possibly_vcf
+{
+    my ($line, $lineno) = (shift, shift);
+    return (($lineno == 1 && $line =~ /##fileformat=VCFv/) ||
+            ($lineno == 2 && $line =~ /##fileDate=/));
+}
+
+
+
 1;
