@@ -1,4 +1,3 @@
-# $Id: RandomDistFunctions.pm 16123 2009-09-17 12:57:27Z cjfields $
 #
 # BioPerl module for Bio::Tools::RandomDistFunctions
 #
@@ -32,6 +31,7 @@ Most of the code is based on the C implementation of these routines in
 Mike Sanderson's r8s's package.  See http://loco.biosci.arizona.edu/r8s/ for
 information on his software.
 
+=for comment
 This code tries to be fast and use available faster BigInt and GMP
 library methods when those modules are available.
 
@@ -63,7 +63,7 @@ Report bugs to the Bioperl bug tracking system to help us keep track
 of the bugs and their resolution. Bug reports can be submitted via the
 web:
 
-  http://bugzilla.open-bio.org/
+  https://github.com/bioperl/bioperl-live/issues
 
 =head1 AUTHOR - Jason Stajich
 
@@ -86,11 +86,12 @@ Internal methods are usually preceded with a _
 
 
 package Bio::Tools::RandomDistFunctions;
+$Bio::Tools::RandomDistFunctions::VERSION = '1.7.8';
 require Exporter;
 use vars qw(%LOADED @EXPORT_OK); use strict;
 
 #use Math::BigFloat lib => 'GMP,Bit::Vector';
-#use Math::BigInt lib  => 'GMP,Bit::Vector';
+#use Math::BigInt   lib => 'GMP,Bit::Vector';
 use POSIX;
 
 use base qw(Bio::Root::Root);
@@ -128,7 +129,7 @@ sub rand_birth_distribution{
  Title   : rand_geometric_distribution
  Usage   : my $randvar = $dist->rand_geometric_distribution($param);
  Function: Returns a random geometric variate distributed with 
-           paramater $param, according to
+           parameter $param, according to
            c.d.f. 1 - ( 1- param) ^ n 
  Returns : integer
  Args    : $param ( 0 > $param < 1 )
