@@ -1,8 +1,7 @@
-# $Id: WrapperBase.pm 16123 2009-09-17 12:57:27Z cjfields $
 #
 # BioPerl module for Bio::Tools::Run::WrapperBase
 #
-# Please direct questions and support issues to <bioperl-l@bioperl.org> 
+# Please direct questions and support issues to <bioperl-l@bioperl.org>
 #
 # Cared for by Jason Stajich <jason@bioperl.org>
 #
@@ -47,15 +46,15 @@ the Bioperl mailing list.  Your participation is much appreciated.
   bioperl-l@bioperl.org                  - General discussion
   http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
 
-=head2 Support 
+=head2 Support
 
 Please direct usage questions or support issues to the mailing list:
 
 I<bioperl-l@bioperl.org>
 
-rather than to the module maintainer directly. Many experienced and 
-reponsive experts will be able look at the problem and quickly 
-address it. Please include a thorough description of the problem 
+rather than to the module maintainer directly. Many experienced and
+reponsive experts will be able look at the problem and quickly
+address it. Please include a thorough description of the problem
 with code and data examples if at all possible.
 
 =head2 Reporting Bugs
@@ -64,7 +63,7 @@ Report bugs to the Bioperl bug tracking system to help us keep track of
 the bugs and their resolution. Bug reports can be submitted via the
 web:
 
-  http://bugzilla.open-bio.org/
+  https://github.com/bioperl/bioperl-live/issues
 
 =head1 AUTHOR - Jason Stajich
 
@@ -86,6 +85,7 @@ Internal methods are usually preceded with a _
 
 
 package Bio::Tools::Run::WrapperBase;
+$Bio::Tools::Run::WrapperBase::VERSION = '1.7.8';
 use strict;
 
 # Object preamble - inherits from Bio::Root::Root
@@ -136,7 +136,7 @@ sub error_string{
 
  Title   : arguments
  Usage   : $obj->arguments($newval)
- Function: Commandline parameters 
+ Function: Commandline parameters
  Returns : value of arguments
  Args    : newvalue (optional)
 
@@ -179,8 +179,8 @@ sub no_param_checks{
  Usage   : $obj->save_tempfiles($newval)
  Function: Get/set the choice of if tempfiles in the temp dir (see tempdir())
            are kept or cleaned up. Default is '0', ie. delete temp files.
-           NB:This must be set to the desired value PRIOR to first creating
-           a temp dir with tempdir().
+           NB: This must be set to the desired value PRIOR to first creating
+           a temp dir with tempdir(). Any attempt to set this after tempdir creation will get a warning.
  Returns : boolean
  Args    : none to get, boolean to set
 
@@ -188,6 +188,10 @@ sub no_param_checks{
 
 sub save_tempfiles{
     my $self = shift;
+    my @args = @_;
+    if (($args[0]) && (exists ($self->{'_tmpdir'}))) {
+        $self->warn ("Tempdir already created; setting save_tempfiles will not affect cleanup behavior.");
+    }
     return $self->io->save_tempfiles(@_);
 }
 
@@ -205,7 +209,7 @@ sub save_tempfiles{
 
 sub outfile_name{
    my ($self,$nm) = @_;
-   if( defined $nm || ! defined $self->{'_outfilename'} ) { 
+   if( defined $nm || ! defined $self->{'_outfilename'} ) {
        $nm = 'mlc' unless defined $nm;
        $self->{'_outfilename'} = $nm;
    }
@@ -281,7 +285,7 @@ sub io{
  Title   : version
  Usage   : $version = $wrapper->version()
  Function: Returns the program version (if available)
- Returns : string representing version of the program 
+ Returns : string representing version of the program
  Args    : [Optional] value to (re)set version string
 
 
@@ -305,16 +309,16 @@ sub version{
 
 sub executable {
     my ($self, $exe, $warn) = @_;
-    
+
     if (defined $exe) {
         $self->{'_pathtoexe'} = $exe;
     }
-    
+
     unless( defined $self->{'_pathtoexe'} ) {
         my $prog_path = $self->program_path;
-        
+
         if ($prog_path) {
-            if (-e $prog_path && -x $prog_path) {
+            if (-f $prog_path && -x $prog_path) {
                 $self->{'_pathtoexe'} = $prog_path;
             }
             elsif ($self->program_dir) {
@@ -323,7 +327,7 @@ sub executable {
         }
         unless ($self->{'_pathtoexe'}) {
             my $exe;
-            if (($exe = $self->io->exists_exe($self->program_name)) && -x $exe) {
+            if ( $exe = $self->io->exists_exe($self->program_name) ) {
                 $self->{'_pathtoexe'} = $exe;
             }
             else {
@@ -332,14 +336,20 @@ sub executable {
             }
         }
     }
-    $self->{'_pathtoexe'};
+
+    # bail if we never found the executable
+    unless ( defined $self->{'_pathtoexe'}) {
+        $self->throw("Cannot find executable for ".$self->program_name .
+            ". path=\"".$self->program_path."\"");
+    }
+    return $self->{'_pathtoexe'};
 }
 
 =head2 program_path
 
  Title   : program_path
  Usage   : my $path = $factory->program_path();
- Function: Builds path for executable 
+ Function: Builds path for executable
  Returns : string representing the full path to the exe
  Args    : none
 
@@ -359,8 +369,8 @@ sub program_path {
  Usage   : my $dir = $factory->program_dir();
  Function: Abstract get method for dir of program. To be implemented
            by wrapper.
- Returns : string representing program directory 
- Args    : none 
+ Returns : string representing program directory
+ Args    : none
 
 =cut
 
@@ -442,7 +452,7 @@ sub quiet {
 
 sub _setparams {
     my ($self, @args) = @_;
-    
+
     my ($params, $switches, $join, $lc, $d, $dd, $md, $utd) =
         $self->_rearrange([qw(PARAMS
                               SWITCHES
@@ -455,32 +465,38 @@ sub _setparams {
     $self->throw('at least one of -params or -switches is required') unless ($params || $switches);
     $self->throw("-dash, -double_dash and -mixed_dash are mutually exclusive") if (defined($d) + defined($dd) + defined($md) > 1);
     $join ||= ' ';
-    
+
     my %params = ref($params) eq 'HASH' ? %{$params} : map { $_ => $_ } @{$params};
     my %switches = ref($switches) eq 'HASH' ? %{$switches} : map { $_ => $_ } @{$switches};
-    
+
     my $param_string = '';
     for my $hash_ref (\%params, \%switches) {
         while (my ($method, $method_out) = each %{$hash_ref}) {
             my $value = $self->$method();
             next unless (defined $value);
             next if (exists $switches{$method} && ! $value);
-            
+
             $method_out = lc($method_out) if $lc;
             my $method_length = length($method_out) if $md;
             $method_out = '-'.$method_out if ($d || ($md && ($method_length == 1)));
             $method_out = '--'.$method_out if ($dd || ($md && ($method_length > 1)));
             $method_out =~ s/_/-/g if $utd;
-            
-            # quote values that contain spaces
-            if (exists $params{$method} && $value =~ /^[^'"\s]+\s+[^'"\s]+$/) {
-                $value = '"'.$value.'"';
+
+            if ( exists $params{$method} ) {
+              # if value are quoted with " or ', re-quote it
+              if ( $value =~ m{^[\'\"]+(.+)[\'\"]+$} ) {
+                $value = '"'. $1 . '"';
+              }
+              # quote values that contain spaces
+              elsif ( $value =~ m{\s+} ) {
+                $value = '"'. $value . '"';
+              }
             }
-            
+
             $param_string .= ' '.$method_out.(exists $switches{$method} ? '' : $join.$value);
         }
     }
-    
+
     return $param_string;
 }
 
