@@ -2,7 +2,6 @@
 # PACKAGE : Bio::Tools::Sigcleave
 # AUTHOR  : Chris Dagdigian, dag@sonsorol.org
 # CREATED : Jan 28 1999
-# REVISION: $Id: Sigcleave.pm,v 1.19 2004/11/11 03:53:10 bosborne Exp $
 #
 # Copyright (c) 1997-9 bioperl, Chris Dagdigian and others. All Rights Reserved.
 #           This module is free software; you can redistribute it and/or 
@@ -38,14 +37,14 @@ Bio::Tools::Sigcleave - Bioperl object for sigcleave analysis
 
   # this works
   $seq = "MVLLLILSVLLLKEDVRGSAQSSERRVVAHMPGDIIIGALFSVHHQPTVDKVHERKCGAVREQYGI";
-  $sig = new Bio::Tools::Sigcleave(-seq  => $seq,
+  $sig = Bio::Tools::Sigcleave->new(-seq  => $seq,
                                                 -type => 'protein',
                                                 -threshold=>'3.5',
                                                 );
   # but you do:
   $seqobj = Bio::PrimarySeq->new(-seq => $seq);
 
-  $sig = new Bio::Tools::Sigcleave(-seq  => $seqobj,
+  $sig = Bio::Tools::Sigcleave->new(-seq  => $seqobj,
                                                 -threshold=>'3.5',
                                                 );
 
@@ -93,7 +92,7 @@ In both cases, the "threshold" setting controls the score reporting
 level. If no value for threshold is passed in by the user, the code
 defaults to a reporting value of 3.5.
 
-In this implemntation the accessor will never return any
+In this implementation the accessor will never return any
 score/position pair which does not meet the threshold limit. This is
 the slightly different from the behaviour of the 8.1 EGCG sigcleave
 program which will report the highest of the under-threshold results
@@ -126,26 +125,36 @@ When updating and maintaining a module, it helps to know that people
 are actually using it. Let us know if you find a bug, think this code
 is useful or have any improvements/features to suggest.
 
+=head2 Support 
+
+Please direct usage questions or support issues to the mailing list:
+
+I<bioperl-l@bioperl.org>
+
+rather than to the module maintainer directly. Many experienced and 
+reponsive experts will be able look at the problem and quickly 
+address it. Please include a thorough description of the problem 
+with code and data examples if at all possible.
+
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
-the bugs and their resolution. Bug reports can be submitted via email
-or the web:
+the bugs and their resolution. Bug reports can be submitted via the
+web:
 
-    bioperl-bugs@bio.perl.org
-    http://bugzilla.bioperl.org/
+  https://github.com/bioperl/bioperl-live/issues
 
 =head1 AUTHOR
 
-Chris Dagdigian, dag@sonsorol.org  & others
+Chris Dagdigian, dag-at-sonsorol.org  & others
 
 =head1 CONTRIBUTORS
 
-Heikki Lehvaslaiho, heikki@ebi.ac.uk
+Heikki Lehvaslaiho, heikki-at-bioperl-dot-org
 
 =head1 VERSION
 
-Bio::Tools::Sigcleave.pm, $Id: Sigcleave.pm,v 1.19 2004/11/11 03:53:10 bosborne Exp $
+Bio::Tools::Sigcleave, $Id$
 
 =head1 COPYRIGHT
 
@@ -180,11 +189,10 @@ preceded by an underscore ("_").
 #
 
 package Bio::Tools::Sigcleave;
-
-use Bio::Root::Root;
+$Bio::Tools::Sigcleave::VERSION = '1.7.8';
 use Bio::PrimarySeq;
 
-@ISA = qw(Bio::Root::Root);
+use base qw(Bio::Root::Root);
 use strict;
 use vars qw ($ID %WeightTable_euc  %WeightTable_pro );
 $ID  = 'Bio::Tools::Sigcleave';
